@@ -9,21 +9,17 @@
 #  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #  License for the specific language governing permissions and limitations
 #  under the License.
+import collections
+import uuid
 
-import collections.abc
-
-from oslo_policy import policy
 import pecan
 from webob import exc
 
 from barbican import api
-from barbican.common import accept
-from barbican.common import config
+from barbican.common import exception
 from barbican.common import utils
 from barbican import i18n as u
 
-
-CONF = config.CONF
 LOG = utils.getLogger(__name__)
 
 
@@ -33,13 +29,9 @@ def is_json_request_accept(req):
     :param req: HTTP request
     :return: True if need to return JSON response.
     """
-    return (
-        type(req.accept) is accept.NoHeaderType or
-        type(req.accept) is accept.ValidHeaderType and (
-            req.accept.header_value == 'application/json' or
-            req.accept.header_value == '*/*'
-        )
-    )
+    return (not req.accept
+            or req.accept.header_value == 'application/json'
+            or req.accept.header_value == '*/*')
 
 
 def _get_barbican_context(req):
@@ -53,22 +45,27 @@ def _do_enforce_rbac(inst, req, action_name, ctx, **kwargs):
     """Enforce RBAC based on 'request' information."""
     if action_name and ctx:
 
+        # Prepare credentials information.
+        credentials = {
+            'roles': ctx.roles,
+            'user': ctx.user,
+            'project': ctx.project
+        }
+
         # Enforce special case: secret GET decryption
         if 'secret:get' == action_name and not is_json_request_accept(req):
             action_name = 'secret:decrypt'  # Override to perform special rules
 
         target_name, target_data = inst.get_acl_tuple(req, **kwargs)
-        policy_dict = {
-            "enforce_new_defaults": CONF.oslo_policy.enforce_new_defaults
-        }
+        policy_dict = {}
         if target_name and target_data:
             policy_dict['target'] = {target_name: target_data}
 
+        policy_dict.update(kwargs)
         # Enforce access controls.
         if ctx.policy_enforcer:
-            target = flatten(policy_dict)
-            ctx.policy_enforcer.authorize(action_name, target,
-                                          ctx, do_raise=True)
+            ctx.policy_enforcer.enforce(action_name, flatten(policy_dict),
+                                        credentials, do_raise=True)
 
 
 def enforce_rbac(action_name='default'):
@@ -83,7 +80,7 @@ def enforce_rbac(action_name='default'):
             ctx = _get_barbican_context(pecan.request)
             external_project_id = None
             if ctx:
-                external_project_id = ctx.project_id
+                external_project_id = ctx.project
 
             _do_enforce_rbac(inst, pecan.request, action_name, ctx, **kwargs)
             # insert external_project_id as the first arg to the guarded method
@@ -105,16 +102,9 @@ def handle_exceptions(operation_name=u._('System')):
         def handler(inst, *args, **kwargs):
             try:
                 return fn(inst, *args, **kwargs)
-            except exc.HTTPError:
-                LOG.exception('Webob error seen')
-                raise  # Already converted to Webob exception, just reraise
-            # In case PolicyNotAuthorized, we do not want to expose payload by
-            # logging exception, so just LOG.error
-            except policy.PolicyNotAuthorized as pna:
-                status, message = api.generate_safe_exception_message(
-                    operation_name, pna)
-                LOG.error(message)
-                pecan.abort(status, message)
+            except exc.HTTPError as f:
+                LOG.exception(u._LE('Webob error seen'))
+                raise f  # Already converted to Webob exception, just reraise
             except Exception as e:
                 # In case intervening modules have disabled logging.
                 LOG.logger.disabled = False
@@ -137,9 +127,10 @@ def _do_enforce_content_types(pecan_req, valid_content_types):
     """
     if pecan_req.content_type not in valid_content_types:
         m = u._(
-            "Unexpected content type. Expected content types "
+            "Unexpected content type: {type}. Expected content types "
             "are: {expected}"
         ).format(
+            type=pecan_req.content_type.decode('utf-8'),
             expected=valid_content_types
         )
         pecan.abort(415, m)
@@ -159,6 +150,18 @@ def enforce_content_types(valid_content_types=[]):
     return content_types_decorator
 
 
+def assert_is_valid_uuid_from_uri(doubtful_uuid):
+    """Checks if the given string is actually a valid UUID
+
+    This assumes that the uuid comes from a URI.
+    :raises: exception.InvalidUUIDInURI
+    """
+    try:
+        uuid.UUID(doubtful_uuid)
+    except ValueError:
+        raise exception.InvalidUUIDInURI(uuid_string=doubtful_uuid)
+
+
 def flatten(d, parent_key=''):
     """Flatten a nested dictionary
 
@@ -169,7 +172,7 @@ def flatten(d, parent_key=''):
     items = []
     for k, v in d.items():
         new_key = parent_key + '.' + k if parent_key else k
-        if isinstance(v, collections.abc.MutableMapping):
+        if isinstance(v, collections.MutableMapping):
             items.extend(flatten(v, new_key).items())
         else:
             items.append((new_key, v))
@@ -178,22 +181,8 @@ def flatten(d, parent_key=''):
 
 class ACLMixin(object):
 
-    def __init__(self):
-        self.secret = None
-        self.container = None
-
     def get_acl_tuple(self, req, **kwargs):
-        if self.secret is not None:
-            entity = 'secret'
-        elif self.container is not None:
-            entity = 'container'
-        else:
-            return None, None
-        entity_acls = getattr(getattr(self, entity), '{}_acls'.format(entity))
-        acl = self.get_acl_dict_for_user(req, entity_acls)
-        acl['project_id'] = getattr(self, entity).project.external_id
-        acl['creator_id'] = getattr(self, entity).creator_id
-        return entity, acl
+        return None, None
 
     def get_acl_dict_for_user(self, req, acl_list):
         """Get acl operation found for token user in acl list.
@@ -201,11 +190,11 @@ class ACLMixin(object):
         Token user is looked into users list present for each acl operation.
         If there is a match, it means that ACL data is applicable for policy
         logic. Policy logic requires data as dictionary so this method capture
-        acl's operation, project_access data in that format.
+        acl's operation, creator_only data in that format.
 
         For operation value, matching ACL record's operation is stored in dict
         as key and value both.
-        project_access flag is intended to make secret/container private for a
+        creator_only flag is intended to make secret/container private for a
         given operation. It doesn't require user match. So its captured in dict
         format where key is prefixed with related operation and flag is used as
         its value.
@@ -219,40 +208,23 @@ class ACLMixin(object):
         and token user is among the ACL users defined for 'read' and 'list'
         operation.
 
-        {'read': 'read', 'list': 'list', 'read_project_access': True,
-        'list_project_access': True }
+        {'read': 'read', 'list': 'list', 'read_creator_only': False,
+        'list_creator_only': False }
 
         Its possible that ACLs are defined without any user, they just
-        have project_access flag set. This means only creator can read or list
+        have creator_only flag set. This means only creator can read or list
         ACL entities. In that case, dictionary output can be as follows.
 
-        {'read_project_access': False, 'list_project_access': False }
+        {'read_creator_only': True, 'list_creator_only': True }
 
         """
         ctxt = _get_barbican_context(req)
         if not ctxt:
-            return {}
+            return None
         acl_dict = {acl.operation: acl.operation for acl in acl_list
                     if ctxt.user in acl.to_dict_fields().get('users', [])}
-        co_dict = {'%s_project_access' % acl.operation: acl.project_access for
-                   acl in acl_list if acl.project_access is not None}
-        if not co_dict:
-            """
-            The co_dict is empty when the entity (secret or container) has no
-            acls in its acl_list.  This causes any policy with
-
-                "%(target.secret.read_project_access)s"
-            or
-                "%(target.container.read_project_access)s"
-
-            to always evaluate to False.  This is probelmatic because we want
-            to allow project access by default (with additional role checks).
-            To work around this we allow read here.
-
-            When the entity has an acl, co_dict will use the value from the
-            database, and this if statement will be skipped.
-            """
-            co_dict = {'read_project_access': True}
+        co_dict = {'%s_creator_only' % acl.operation: acl.creator_only for acl
+                   in acl_list if acl.creator_only is not None}
         acl_dict.update(co_dict)
 
         return acl_dict
