@@ -15,7 +15,6 @@ import pecan
 from barbican import api
 from barbican.api import controllers
 from barbican.common import hrefs
-from barbican.common import quota
 from barbican.common import resources as res
 from barbican.common import utils
 from barbican.common import validators
@@ -26,13 +25,11 @@ from barbican.queue import client as async_client
 
 LOG = utils.getLogger(__name__)
 
-_DEPRECATION_MSG = '%s has been deprecated in the Newton release. ' \
-                   'It will be removed in the Pike release.'
-
 
 def _order_not_found():
     """Throw exception indicating order not found."""
-    pecan.abort(404, u._('Order not found.'))
+    pecan.abort(404, u._('Not Found. Sorry but your order is in '
+                         'another castle.'))
 
 
 def _secret_not_in_order():
@@ -45,6 +42,12 @@ def _order_update_not_supported():
     pecan.abort(405, u._("Order update is not supported."))
 
 
+def _order_update_not_supported_for_type(order_type):
+    """Throw exception that update is not supported."""
+    pecan.abort(400, u._("Updates are not supported for order type "
+                         "{0}.").format(order_type))
+
+
 def _order_cannot_be_updated_if_not_pending(order_status):
     """Throw exception that order cannot be updated if not PENDING."""
     pecan.abort(400, u._("Only PENDING orders can be updated. Order is in the"
@@ -61,18 +64,11 @@ class OrderController(controllers.ACLMixin):
     """Handles Order retrieval and deletion requests."""
 
     def __init__(self, order, queue_resource=None):
-        super().__init__()
         self.order = order
         self.order_repo = repo.get_order_repository()
         self.queue = queue_resource or async_client.TaskClient()
         self.type_order_validator = validators.TypeOrderValidator()
 
-    def get_acl_tuple(self, req, **kwargs):
-        acl = dict()
-        acl['project_id'] = self.order.project.external_id
-        acl['creator_id'] = self.order.creator_id
-        return 'order', acl
-
     @pecan.expose(generic=True)
     def index(self, **kwargs):
         pecan.abort(405)  # HTTP 405 Method Not Allowed as default
@@ -83,6 +79,35 @@ class OrderController(controllers.ACLMixin):
     def on_get(self, external_project_id):
         return hrefs.convert_to_hrefs(self.order.to_dict_fields())
 
+    @index.when(method='PUT')
+    @controllers.handle_exceptions(u._('Order update'))
+    @controllers.enforce_rbac('order:put')
+    @controllers.enforce_content_types(['application/json'])
+    def on_put(self, external_project_id, **kwargs):
+        body = api.load_body(pecan.request,
+                             validator=self.type_order_validator)
+
+        project = res.get_or_create_project(external_project_id)
+        order_type = body.get('type')
+
+        if self.order.type != order_type:
+            order_cannot_modify_order_type()
+
+        if models.OrderType.CERTIFICATE != self.order.type:
+            _order_update_not_supported_for_type(order_type)
+
+        if models.States.PENDING != self.order.status:
+            _order_cannot_be_updated_if_not_pending(self.order.status)
+
+        updated_meta = body.get('meta')
+        validators.validate_ca_id(project.id, updated_meta)
+
+        # TODO(chellygel): Put 'meta' into a separate order association
+        # entity.
+        self.queue.update_order(order_id=self.order.id,
+                                project_id=external_project_id,
+                                updated_meta=updated_meta)
+
     @index.when(method='DELETE')
     @utils.allow_all_content_types
     @controllers.handle_exceptions(u._('Order deletion'))
@@ -97,12 +122,11 @@ class OrdersController(controllers.ACLMixin):
     """Handles Order requests for Secret creation."""
 
     def __init__(self, queue_resource=None):
+
         LOG.debug('Creating OrdersController')
-        super().__init__()
         self.order_repo = repo.get_order_repository()
         self.queue = queue_resource or async_client.TaskClient()
         self.type_order_validator = validators.TypeOrderValidator()
-        self.quota_enforcer = quota.QuotaEnforcer('orders', self.order_repo)
 
     @pecan.expose()
     def _lookup(self, order_id, *remainder):
@@ -110,11 +134,11 @@ class OrdersController(controllers.ACLMixin):
         # actually does a lookup in the database regardless of the RBAC policy
         # check, the execution only gets here if authentication of the user was
         # previously successful.
-
+        controllers.assert_is_valid_uuid_from_uri(order_id)
         ctx = controllers._get_barbican_context(pecan.request)
 
         order = self.order_repo.get(entity_id=order_id,
-                                    external_project_id=ctx.project_id,
+                                    external_project_id=ctx.project,
                                     suppress_exception=True)
         if not order:
             _order_not_found()
@@ -134,8 +158,7 @@ class OrdersController(controllers.ACLMixin):
 
         result = self.order_repo.get_by_create_date(
             external_project_id, offset_arg=kw.get('offset', 0),
-            limit_arg=kw.get('limit', None), meta_arg=kw.get('meta', None),
-            suppress_exception=True)
+            limit_arg=kw.get('limit', None), suppress_exception=True)
         orders, offset, limit, total = result
 
         if not orders:
@@ -164,6 +187,7 @@ class OrdersController(controllers.ACLMixin):
     @controllers.enforce_rbac('orders:post')
     @controllers.enforce_content_types(['application/json'])
     def on_post(self, external_project_id, **kwargs):
+
         project = res.get_or_create_project(external_project_id)
 
         body = api.load_body(pecan.request,
@@ -173,23 +197,25 @@ class OrdersController(controllers.ACLMixin):
         order_meta = body.get('meta')
         request_type = order_meta.get('request_type')
 
-        LOG.debug('Processing order type %(order_type)s,'
-                  ' request type %(request_type)s' %
-                  {'order_type': order_type,
-                   'request_type': request_type})
+        LOG.debug('Processing order type %s, request type %s',
+                  order_type, request_type)
 
-        self.quota_enforcer.enforce(project)
+        if order_type == models.OrderType.CERTIFICATE:
+            validators.validate_ca_id(project.id, body.get('meta'))
+            if request_type == 'stored-key':
+                container_ref = order_meta.get('container_ref')
+                validators.validate_stored_key_rsa_container(
+                    external_project_id,
+                    container_ref)
 
         new_order = models.Order()
         new_order.meta = body.get('meta')
         new_order.type = order_type
         new_order.project_id = project.id
 
-        request_id = None
         ctxt = controllers._get_barbican_context(pecan.request)
         if ctxt:
-            new_order.creator_id = ctxt.user_id
-            request_id = ctxt.request_id
+            new_order.creator_id = ctxt.user
 
         self.order_repo.create_from(new_order)
 
@@ -200,8 +226,7 @@ class OrdersController(controllers.ACLMixin):
         repo.commit()
 
         self.queue.process_type_order(order_id=order_id,
-                                      project_id=external_project_id,
-                                      request_id=request_id)
+                                      project_id=external_project_id)
 
         url = hrefs.convert_order_to_href(order_id)
 
