@@ -17,11 +17,18 @@
 Barbican exception subclasses
 """
 
+import urlparse
+
 from barbican import i18n as u
 
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 
 
+class RedirectException(Exception):
+    def __init__(self, url):
+        self.url = urlparse.urlparse(url)
+
+
 class BarbicanException(Exception):
     """Base Barbican Exception
 
@@ -89,18 +96,6 @@ class MissingMetadataField(BarbicanHTTPException):
     status_code = 400
 
 
-class InvalidMetadataRequest(BarbicanHTTPException):
-    message = u._("Invalid Metadata. Keys and Values must be Strings.")
-    client_message = message
-    status_code = 400
-
-
-class InvalidMetadataKey(BarbicanHTTPException):
-    message = u._("Invalid Key. Key must be URL safe.")
-    client_message = message
-    status_code = 400
-
-
 class InvalidSubjectDN(BarbicanHTTPException):
     message = u._("Invalid subject DN: %(subject_dn)s")
     client_message = message
@@ -268,7 +263,7 @@ class MultipleChoices(BarbicanException):
 class LimitExceeded(BarbicanHTTPException):
     message = u._("The request returned a 413 Request Entity Too Large. This "
                   "generally means that rate limiting or a quota threshold "
-                  "was breached.")
+                  "was breached.\n\nThe response body:\n%(body)s")
     client_message = u._("Provided information too large to process")
     status_code = 413
 
@@ -279,7 +274,7 @@ class LimitExceeded(BarbicanHTTPException):
 
 
 class ServiceUnavailable(BarbicanException):
-    message = u._("The request returned 503 Service Unavailable. This "
+    message = u._("The request returned 503 Service Unavilable. This "
                   "generally occurs on service overload or other transient "
                   "outage.")
 
@@ -369,8 +364,7 @@ class InvalidObject(BarbicanHTTPException):
         self.message = u._("Failed to validate JSON information: ")
         self.client_message = u._("Provided object does not match "
                                   "schema '{schema}': "
-                                  "{reason}. Invalid property: "
-                                  "'{property}'").format(*args, **kwargs)
+                                  "{reason}").format(*args, **kwargs)
         self.message = self.message + self.client_message
         super(InvalidObject, self).__init__(*args, **kwargs)
 
@@ -424,11 +418,11 @@ class StoredKeyPrivateKeyNotFound(BarbicanException):
                   "key needed for stored key certificate generation.")
 
 
-class ProvidedTransportKeyNotFound(BarbicanHTTPException):
-    message = u._("Provided Transport key %(transport_key_id)s "
-                  "could not be found")
-    client_message = u._("Provided transport key was not found.")
-    status_code = 400
+class InvalidUUIDInURI(BarbicanHTTPException):
+    message = u._("The provided UUID in the URI (%(uuid_string)s) is "
+                  "malformed.")
+    client_message = u._("The provided UUID in the URI is malformed.")
+    status_code = 404
 
 
 class InvalidCAID(BarbicanHTTPException):
@@ -443,147 +437,3 @@ class CANotDefinedForProject(BarbicanHTTPException):
     client_message = u._("The ca_id provided in the request is not defined "
                          "for this project")
     status_code = 403
-
-
-class QuotaReached(BarbicanHTTPException):
-    message = u._("Quota reached for project %(external_project_id)s. Only "
-                  "%(quota)s %(resource_type)s are allowed.")
-    client_message = u._("Creation not allowed because a quota has "
-                         "been reached")
-    status_code = 403
-
-    def __init__(self, *args, **kwargs):
-        super(QuotaReached, self).__init__(*args, **kwargs)
-        self.external_project_id = kwargs.get('external_project_id')
-        self.quota = kwargs.get('quota')
-        self.resource_type = kwargs.get('resource_type')
-
-
-class InvalidParentCA(BarbicanHTTPException):
-    message = u._("Invalid Parent CA: %(parent_ca_ref)s")
-    client_message = message
-    status_code = 400
-
-
-class SubCAsNotSupported(BarbicanHTTPException):
-    message = u._("Plugin does not support generation of subordinate CAs")
-    client_message = message
-    status_code = 400
-
-
-class SubCANotCreated(BarbicanHTTPException):
-    message = u._("Errors in creating subordinate CA: %(name)")
-    client_message = message
-
-
-class CannotDeleteBaseCA(BarbicanHTTPException):
-    message = u._("Only subordinate CAs can be deleted.")
-    status_code = 403
-
-
-class UnauthorizedSubCA(BarbicanHTTPException):
-    message = u._("Subordinate CA is not owned by this project")
-    client_message = message
-    status_code = 403
-
-
-class CannotDeletePreferredCA(BarbicanHTTPException):
-    message = u._("A new project preferred CA must be set "
-                  "before this one can be deleted.")
-    status_code = 409
-
-
-class BadSubCACreationRequest(BarbicanHTTPException):
-    message = u._("Errors returned by CA when attempting to "
-                  "create subordinate CA: %(reason)s")
-    client_message = message
-    status_code = 400
-
-
-class SubCACreationErrors(BarbicanHTTPException):
-    message = u._("Errors returned by CA when attempting to create "
-                  "subordinate CA: %(reason)s")
-    client_message = message
-
-
-class SubCADeletionErrors(BarbicanHTTPException):
-    message = u._("Errors returned by CA when attempting to delete "
-                  "subordinate CA: %(reason)s")
-    client_message = message
-
-
-class PKCS11Exception(BarbicanException):
-    message = u._("There was an error with the PKCS#11 library.")
-
-
-class P11CryptoPluginKeyException(PKCS11Exception):
-    message = u._("More than one key found for label")
-
-
-class P11CryptoPluginException(PKCS11Exception):
-    message = u._("General exception")
-
-
-class P11CryptoKeyHandleException(PKCS11Exception):
-    message = u._("No key handle was found")
-
-
-class P11CryptoTokenException(PKCS11Exception):
-    message = u._("No token was found in slot %(slot_id)s")
-
-
-class MultipleStorePreferredPluginMissing(BarbicanException):
-    """Raised when a preferred plugin is missing in service configuration."""
-    def __init__(self, store_name):
-        super(MultipleStorePreferredPluginMissing, self).__init__(
-            u._("Preferred Secret Store plugin '{store_name}' is not "
-                "currently set in service configuration. This is probably a "
-                "server misconfiguration.").format(
-                store_name=store_name)
-        )
-        self.store_name = store_name
-
-
-class MultipleStorePluginStillInUse(BarbicanException):
-    """Raised when a used plugin is missing in service configuration."""
-    def __init__(self, store_name):
-        super(MultipleStorePluginStillInUse, self).__init__(
-            u._("Secret Store plugin '{store_name}' is still in use and can "
-                "not be removed. Its missing in service configuration. This is"
-                " probably a server misconfiguration.").format(
-                store_name=store_name)
-        )
-        self.store_name = store_name
-
-
-class MultipleSecretStoreLookupFailed(BarbicanException):
-    """Raised when a plugin lookup suffix is missing during config read."""
-    def __init__(self):
-        msg = u._("Plugin lookup property 'stores_lookup_suffix' is not "
-                  "defined in service configuration")
-        super(MultipleSecretStoreLookupFailed, self).__init__(msg)
-
-
-class MultipleStoreIncorrectGlobalDefault(BarbicanException):
-    """Raised when a global default for only one plugin is not set to True."""
-    def __init__(self, occurence):
-        msg = None
-        if occurence > 1:
-            msg = u._("There are {count} plugins with global default as "
-                      "True in service configuration. Only one plugin can have"
-                      " this as True").format(count=occurence)
-        else:
-            msg = u._("There is no plugin defined with global default as True."
-                      " One of plugin must be identified as global default")
-
-        super(MultipleStoreIncorrectGlobalDefault, self).__init__(msg)
-
-
-class MultipleStorePluginValueMissing(BarbicanException):
-    """Raised when a store plugin value is missing in service configuration."""
-    def __init__(self, section_name):
-        super(MultipleStorePluginValueMissing, self).__init__(
-            u._("In section '{0}', secret_store_plugin value is missing"
-                ).format(section_name)
-        )
-        self.section_name = section_name
