@@ -12,41 +12,29 @@
 # limitations under the License.
 import os
 
+from Crypto.PublicKey import DSA
+from Crypto.PublicKey import RSA
+from Crypto.Util import asn1
 from cryptography import fernet
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives.asymmetric import dsa
-from cryptography.hazmat.primitives.asymmetric import rsa
-from cryptography.hazmat.primitives import serialization
 from oslo_config import cfg
-from oslo_utils import encodeutils
+import six
 
-from barbican.common import config
-from barbican.common import utils
 from barbican import i18n as u
-from barbican.plugin.crypto import base as c
+from barbican.plugin.crypto import crypto as c
 
 
-CONF = config.new_config()
-LOG = utils.getLogger(__name__)
+CONF = cfg.CONF
 
 simple_crypto_plugin_group = cfg.OptGroup(name='simple_crypto_plugin',
                                           title="Simple Crypto Plugin Options")
 simple_crypto_plugin_opts = [
     cfg.StrOpt('kek',
-               default='dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
+               default=b'dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
                help=u._('Key encryption key to be used by Simple Crypto '
-                        'Plugin'), secret=True),
-    cfg.StrOpt('plugin_name',
-               help=u._('User friendly plugin name'),
-               default='Software Only Crypto'),
+                        'Plugin'))
 ]
 CONF.register_group(simple_crypto_plugin_group)
 CONF.register_opts(simple_crypto_plugin_opts, group=simple_crypto_plugin_group)
-config.parse_args(CONF)
-
-
-def list_opts():
-    yield simple_crypto_plugin_group, simple_crypto_plugin_opts
 
 
 class SimpleCryptoPlugin(c.CryptoPluginBase):
@@ -54,11 +42,6 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
 
     def __init__(self, conf=CONF):
         self.master_kek = conf.simple_crypto_plugin.kek
-        self.plugin_name = conf.simple_crypto_plugin.plugin_name
-        LOG.info("{} initialized".format(self.plugin_name))
-
-    def get_plugin_name(self):
-        return self.plugin_name
 
     def _get_kek(self, kek_meta_dto):
         if not kek_meta_dto.plugin_meta:
@@ -66,7 +49,7 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
         # the kek is stored encrypted. Need to decrypt.
         encryptor = fernet.Fernet(self.master_kek)
         # Note : If plugin_meta type is unicode, encode to byte.
-        if isinstance(kek_meta_dto.plugin_meta, str):
+        if isinstance(kek_meta_dto.plugin_meta, six.text_type):
             kek_meta_dto.plugin_meta = kek_meta_dto.plugin_meta.encode('utf-8')
 
         return encryptor.decrypt(kek_meta_dto.plugin_meta)
@@ -74,7 +57,7 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
     def encrypt(self, encrypt_dto, kek_meta_dto, project_id):
         kek = self._get_kek(kek_meta_dto)
         unencrypted = encrypt_dto.unencrypted
-        if not isinstance(unencrypted, bytes):
+        if not isinstance(unencrypted, str):
             raise ValueError(
                 u._(
                     'Unencrypted data must be a byte type, but was '
@@ -106,7 +89,7 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
         return kek_meta_dto
 
     def generate_symmetric(self, generate_dto, kek_meta_dto, project_id):
-        byte_length = int(generate_dto.bit_length) // 8
+        byte_length = int(generate_dto.bit_length) / 8
         unencrypted = os.urandom(byte_length)
 
         return self.encrypt(c.EncryptDTO(unencrypted),
@@ -119,50 +102,36 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
         - RSA, with passphrase (supported)
         - RSA, without passphrase (supported)
         - DSA, without passphrase (supported)
-        - DSA, with passphrase (supported)
+        - DSA, with passphrase (not supported)
+
+        Note: PyCrypto is not capable of serializing DSA
+        keys and DER formated keys. Such keys will be
+        serialized to Base64 PEM to store in DB.
+
+        TODO (atiwari/reaperhulk): PyCrypto is not capable to serialize
+        DSA keys and DER formated keys, later we need to pick better
+        crypto lib.
         """
-        if (generate_dto.algorithm is None or generate_dto
+        if(generate_dto.algorithm is None or generate_dto
                 .algorithm.lower() == 'rsa'):
-            private_key = rsa.generate_private_key(
-                public_exponent=65537,
-                key_size=generate_dto.bit_length,
-                backend=default_backend()
-            )
+            private_key = RSA.generate(
+                generate_dto.bit_length, None, None, 65537)
         elif generate_dto.algorithm.lower() == 'dsa':
-            private_key = dsa.generate_private_key(
-                key_size=generate_dto.bit_length,
-                backend=default_backend()
-            )
+            private_key = DSA.generate(generate_dto.bit_length, None, None)
         else:
             raise c.CryptoPrivateKeyFailureException()
 
-        public_key = private_key.public_key()
+        public_key = private_key.publickey()
 
+        # Note (atiwari): key wrapping format PEM only supported
         if generate_dto.algorithm.lower() == 'rsa':
-            private_key = private_key.private_bytes(
-                encoding=serialization.Encoding.PEM,
-                format=serialization.PrivateFormat.PKCS8,
-                encryption_algorithm=self._get_encryption_algorithm(
-                    generate_dto.passphrase)
-            )
-
-            public_key = public_key.public_bytes(
-                encoding=serialization.Encoding.PEM,
-                format=serialization.PublicFormat.SubjectPublicKeyInfo
-            )
-
+            public_key, private_key = self._wrap_key(public_key, private_key,
+                                                     generate_dto.passphrase)
         if generate_dto.algorithm.lower() == 'dsa':
-            private_key = private_key.private_bytes(
-                encoding=serialization.Encoding.DER,
-                format=serialization.PrivateFormat.PKCS8,
-                encryption_algorithm=self._get_encryption_algorithm(
-                    generate_dto.passphrase)
-            )
-            public_key = public_key.public_bytes(
-                encoding=serialization.Encoding.DER,
-                format=serialization.PublicFormat.SubjectPublicKeyInfo
-            )
-
+            if generate_dto.passphrase:
+                raise ValueError(u._('Passphrase not supported for DSA key'))
+            public_key, private_key = self._serialize_dsa_key(public_key,
+                                                              private_key)
         private_dto = self.encrypt(c.EncryptDTO(private_key),
                                    kek_meta_dto,
                                    project_id)
@@ -173,7 +142,7 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
 
         passphrase_dto = None
         if generate_dto.passphrase:
-            if isinstance(generate_dto.passphrase, str):
+            if isinstance(generate_dto.passphrase, six.text_type):
                 generate_dto.passphrase = generate_dto.passphrase.encode(
                     'utf-8')
 
@@ -188,52 +157,48 @@ class SimpleCryptoPlugin(c.CryptoPluginBase):
                  mode=None):
         if type_enum == c.PluginSupportTypes.ENCRYPT_DECRYPT:
             return True
-        elif type_enum == c.PluginSupportTypes.SYMMETRIC_KEY_GENERATION:
+
+        if type_enum == c.PluginSupportTypes.SYMMETRIC_KEY_GENERATION:
             return self._is_algorithm_supported(algorithm,
-                                                bit_length,
-                                                mode)
+                                                bit_length)
         elif type_enum == c.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION:
             return self._is_algorithm_supported(algorithm,
-                                                bit_length,
-                                                mode)
+                                                bit_length)
         else:
             return False
 
-    def _get_encryption_algorithm(self, passphrase):
-        """Choose whether to use encryption or not based on passphrase
+    def _wrap_key(self, public_key, private_key,
+                  passphrase):
+        pkcs = 8
+        key_wrap_format = 'PEM'
 
-        serialization.BestAvailableEncryption fails if passphrase is not
-        given or if less than one byte therefore we need to check if it is
-        valid or not
-        """
-        if passphrase:
-            # encryption requires password in bytes format
-            algorithm = serialization.BestAvailableEncryption(
-                # default encoding is utf-8
-                encodeutils.safe_encode(passphrase)
-            )
-        else:
-            algorithm = serialization.NoEncryption()
+        private_key = private_key.exportKey(key_wrap_format, passphrase, pkcs)
+        public_key = public_key.exportKey(key_wrap_format)
 
-        return algorithm
+        return public_key, private_key
 
-    def _is_algorithm_supported(self, algorithm=None,
-                                bit_length=None, mode=None):
+    def _serialize_dsa_key(self, public_key, private_key):
+
+        pub_seq = asn1.DerSequence()
+        pub_seq[:] = [0, public_key.p, public_key.q,
+                      public_key.g, public_key.y]
+        public_key = pub_seq.encode()
+
+        prv_seq = asn1.DerSequence()
+        prv_seq[:] = [0, private_key.p, private_key.q,
+                      private_key.g, private_key.y, private_key.x]
+        private_key = prv_seq.encode()
+
+        return public_key, private_key
+
+    def _is_algorithm_supported(self, algorithm=None, bit_length=None):
         """check if algorithm and bit_length combination is supported."""
         if algorithm is None or bit_length is None:
             return False
 
-        length_factor = 1
-
-        # xts-mode cuts the effective key for the algorithm in half,
-        # so the bit_length must be the double of the supported length.
-        # in the future there should be a validation of supported modes too.
-        if mode is not None and mode.lower() == "xts":
-            length_factor = 2
-
-        if (algorithm.lower() in c.PluginSupportTypes.SYMMETRIC_ALGORITHMS
-            and bit_length / length_factor
-                in c.PluginSupportTypes.SYMMETRIC_KEY_LENGTHS):
+        if (algorithm.lower() in
+                c.PluginSupportTypes.SYMMETRIC_ALGORITHMS and bit_length in
+                c.PluginSupportTypes.SYMMETRIC_KEY_LENGTHS):
             return True
         elif (algorithm.lower() in c.PluginSupportTypes.ASYMMETRIC_ALGORITHMS
               and bit_length in c.PluginSupportTypes.ASYMMETRIC_KEY_LENGTHS):
