@@ -15,22 +15,13 @@
 
 import base64
 import copy
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import serialization
-import datetime
 import os
-from oslo_utils import uuidutils
-import time
+import uuid
 
+from Crypto.PublicKey import RSA
+from Crypto.Util import asn1
+from oslo_config import cfg
 import pki
-
-subcas_available = True
-try:
-    import pki.authority as authority
-    import pki.feature as feature
-except ImportError:
-    subcas_available = False
-
 import pki.cert
 import pki.client
 import pki.crypto as cryptoutil
@@ -42,102 +33,76 @@ from requests import exceptions as request_exceptions
 from barbican.common import exception
 from barbican.common import utils
 from barbican import i18n as u
-
-# we want to keep the dogtag config options separated. That way we
-# do not need to import every dogtag requirement to generate the
-# sample config
-import barbican.plugin.dogtag_config_opts  # noqa
 import barbican.plugin.interface.certificate_manager as cm
 import barbican.plugin.interface.secret_store as sstore
 
-# reuse the conf object to not call config.new_config() twice
-CONF = barbican.plugin.dogtag_config_opts.CONF
+CONF = cfg.CONF
 LOG = utils.getLogger(__name__)
 
-CERT_HEADER = "-----BEGIN CERTIFICATE-----"
-CERT_FOOTER = "-----END CERTIFICATE-----"
+dogtag_plugin_group = cfg.OptGroup(name='dogtag_plugin',
+                                   title="Dogtag Plugin Options")
+dogtag_plugin_opts = [
+    cfg.StrOpt('pem_path',
+               help=u._('Path to PEM file for authentication')),
+    cfg.StrOpt('dogtag_host',
+               default="localhost",
+               help=u._('Hostname for the Dogtag instance')),
+    cfg.StrOpt('dogtag_port',
+               default="8443",
+               help=u._('Port for the Dogtag instance')),
+    cfg.StrOpt('nss_db_path',
+               help=u._('Path to the NSS certificate database for the KRA')),
+    cfg.StrOpt('nss_db_path_ca',
+               help=u._('Path to the NSS certificate database for the CA')),
+    cfg.StrOpt('nss_password',
+               help=u._('Password for the NSS certificate databases')),
+    cfg.StrOpt('simple_cmc_profile',
+               help=u._('Profile for simple CMC requests')),
+    cfg.StrOpt('auto_approved_profiles',
+               default="caServerCert",
+               help=u._('List of automatically approved enrollment profiles'))
+]
 
-KRA_TRANSPORT_NICK = "KRA transport cert"
+CONF.register_group(dogtag_plugin_group)
+CONF.register_opts(dogtag_plugin_opts, group=dogtag_plugin_group)
 
 
-def _create_nss_db_if_needed(nss_db_path, nss_password):
-    """Creates NSS DB if it's not setup already
-
-    :returns: True or False whether the database was created or not.
-    """
-    if not os.path.exists(nss_db_path):
-        cryptoutil.NSSCryptoProvider.setup_database(
-            nss_db_path, nss_password, over_write=True)
-        return True
+def setup_nss_db(conf, subsystem):
+    crypto = None
+    create_nss_db = False
+    if subsystem == 'ca':
+        nss_db_path = conf.dogtag_plugin.nss_db_path_ca
     else:
-        LOG.info("The nss_db_path provided already exists, so the "
-                 "database is assumed to be already set up.")
-        return False
+        nss_db_path = conf.dogtag_plugin.nss_db_path
 
+    if nss_db_path is not None:
+        nss_password = conf.dogtag_plugin.nss_password
+        if nss_password is None:
+            raise ValueError(u._("nss_password is required"))
 
-def _setup_nss_db_services(conf):
-    """Sets up NSS Crypto functions
+        if not os.path.exists(nss_db_path):
+            create_nss_db = True
+            cryptoutil.NSSCryptoProvider.setup_database(
+                nss_db_path, nss_password, over_write=True)
 
-    This sets up the NSSCryptoProvider and the database it needs for it to
-    store certificates. If the path specified in the configuration is already
-    existent, it will assume that the database is already setup.
+        crypto = cryptoutil.NSSCryptoProvider(nss_db_path, nss_password)
 
-    This will also import the transport cert needed by the KRA if the NSS DB
-    was created.
-    """
-    nss_db_path, nss_password = (conf.dogtag_plugin.nss_db_path,
-                                 conf.dogtag_plugin.nss_password)
-    if nss_db_path is None:
-        LOG.warning("nss_db_path was not provided so the crypto "
-                    "provider functions were not initialized.")
-        return None
-    if nss_password is None:
-        raise ValueError(u._("nss_password is required"))
-    if type(nss_password) is not bytes:
-        # Password needs to be a bytes object in Python 3
-        nss_password = nss_password.encode('UTF-8')
-
-    nss_db_created = _create_nss_db_if_needed(nss_db_path, nss_password)
-    crypto = cryptoutil.NSSCryptoProvider(nss_db_path, nss_password)
-    if nss_db_created:
-        _import_kra_transport_cert_to_nss_db(conf, crypto)
-
-    return crypto
-
-
-def _import_kra_transport_cert_to_nss_db(conf, crypto):
-    try:
-        connection = create_connection(conf, 'kra')
-        kraclient = pki.kra.KRAClient(connection, crypto)
-        systemcert_client = kraclient.system_certs
-
-        transport_cert = systemcert_client.get_transport_cert()
-        crypto.import_cert(KRA_TRANSPORT_NICK, transport_cert, ",,")
-    except Exception as e:
-        LOG.debug("Error importing KRA transport cert.", exc_info=True)
-        LOG.error("Error in importing transport cert."
-                  " KRA may not be enabled: %s", e)
+    return crypto, create_nss_db
 
 
 def create_connection(conf, subsystem_path):
     pem_path = conf.dogtag_plugin.pem_path
     if pem_path is None:
         raise ValueError(u._("pem_path is required"))
-    # port is string type in PKIConnection
     connection = pki.client.PKIConnection(
         'https',
         conf.dogtag_plugin.dogtag_host,
-        str(conf.dogtag_plugin.dogtag_port),
+        conf.dogtag_plugin.dogtag_port,
         subsystem_path)
     connection.set_authentication_cert(pem_path)
     return connection
 
 
-crypto = _setup_nss_db_services(CONF)
-if crypto:
-    crypto.initialize()
-
-
 class DogtagPluginAlgorithmException(exception.BarbicanException):
     message = u._("Invalid algorithm passed in")
 
@@ -154,24 +119,18 @@ class DogtagPluginNotSupportedException(exception.NotSupported):
         super(DogtagPluginNotSupportedException, self).__init__(message)
 
 
-class DogtagPluginArchivalException(exception.BarbicanException):
-    message = u._("Key archival failed.  Error returned from KRA.")
-
-
-class DogtagPluginGenerationException(exception.BarbicanException):
-    message = u._("Key generation failed.  Error returned from KRA.")
-
-
 class DogtagKRAPlugin(sstore.SecretStoreBase):
     """Implementation of the secret store plugin with KRA as the backend."""
 
+    TRANSPORT_NICK = "KRA transport cert"
+
     # metadata constants
     ALG = "alg"
     BIT_LENGTH = "bit_length"
     GENERATED = "generated"
     KEY_ID = "key_id"
-    SECRET_MODE = "secret_mode"  # nosec
-    PASSPHRASE_KEY_ID = "passphrase_key_id"  # nosec
+    SECRET_MODE = "secret_mode"
+    PASSPHRASE_KEY_ID = "passphrase_key_id"
     CONVERT_TO_PEM = "convert_to_pem"
 
     # string constants
@@ -183,20 +142,30 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
     def __init__(self, conf=CONF):
         """Constructor - create the keyclient."""
         LOG.debug("starting DogtagKRAPlugin init")
+        crypto, create_nss_db = setup_nss_db(conf, 'kra')
         connection = create_connection(conf, 'kra')
 
         # create kraclient
         kraclient = pki.kra.KRAClient(connection, crypto)
         self.keyclient = kraclient.keys
+        self.systemcert_client = kraclient.system_certs
 
-        self.keyclient.set_transport_cert(KRA_TRANSPORT_NICK)
-        self.plugin_name = conf.dogtag_plugin.plugin_name
-        self.retries = conf.dogtag_plugin.retries
+        if crypto is not None:
+            if create_nss_db:
+                self.import_transport_cert(crypto)
+
+            crypto.initialize()
+            self.keyclient.set_transport_cert(
+                DogtagKRAPlugin.TRANSPORT_NICK)
 
         LOG.debug("completed DogtagKRAPlugin init")
 
-    def get_plugin_name(self):
-        return self.plugin_name
+    def import_transport_cert(self, crypto):
+        # Get transport cert and insert in the certdb
+        transport_cert = self.systemcert_client.get_transport_cert()
+        crypto.import_cert(DogtagKRAPlugin.TRANSPORT_NICK,
+                           transport_cert,
+                           "u,u,u")
 
     def store_secret(self, secret_dto):
         """Store a secret in the KRA
@@ -218,41 +187,25 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         the key_id
         """
         data_type = key.KeyClient.PASS_PHRASE_TYPE
-        key_id = None
+        client_key_id = uuid.uuid4().hex
+        if secret_dto.transport_key is not None:
+            # TODO(alee-3) send the transport key with the archival request
+            # once the Dogtag Client API changes.
+            response = self.keyclient.archive_pki_options(
+                client_key_id,
+                data_type,
+                secret_dto.secret,
+                key_algorithm=None,
+                key_size=None)
+        else:
+            response = self.keyclient.archive_key(
+                client_key_id,
+                data_type,
+                secret_dto.secret,
+                key_algorithm=None,
+                key_size=None)
 
-        attempts = 0
-        offset_time = 1
-        while attempts <= self.retries and key_id is None:
-            client_key_id = uuidutils.generate_uuid(dashed=False)
-            if secret_dto.transport_key is not None:
-                # TODO(alee-3) send the transport key with the archival request
-                # once the Dogtag Client API changes.
-                response = self.keyclient.archive_pki_options(
-                    client_key_id,
-                    data_type,
-                    secret_dto.secret,
-                    key_algorithm=None,
-                    key_size=None)
-            else:
-                response = self.keyclient.archive_key(
-                    client_key_id,
-                    data_type,
-                    secret_dto.secret,
-                    key_algorithm=None,
-                    key_size=None)
-
-            key_id = response.get_key_id()
-
-            if key_id is None:
-                LOG.warning("key_id is None.  attempts: {}".format(attempts))
-                attempts += 1
-                time.sleep(offset_time)
-                offset_time += 1
-
-        if key_id is None:
-            raise DogtagPluginArchivalException
-
-        meta_dict = {DogtagKRAPlugin.KEY_ID: key_id}
+        meta_dict = {DogtagKRAPlugin.KEY_ID: response.get_key_id()}
 
         self._store_secret_attributes(meta_dict, secret_dto)
         return meta_dict
@@ -321,32 +274,51 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
                 # as it is treated as an attribute of the asymmetric key pair
                 # stored in the KRA database.
 
+                if key_spec.alg is None:
+                    raise sstore.SecretAlgorithmNotSupportedException('None')
+
                 key_info = self.keyclient.get_key_info(key_id)
-                recovered_key = serialization.load_der_public_key(
-                    key_info.public_key,
-                    backend=default_backend()
-                ).public_bytes(
-                    serialization.Encoding.PEM,
-                    serialization.PublicFormat.PKCS1)
+                if key_spec.alg.upper() == key.KeyClient.RSA_ALGORITHM:
+                    recovered_key = (RSA.importKey(key_info.public_key)
+                                     .publickey()
+                                     .exportKey('PEM')).encode('utf-8')
+                elif key_spec.alg.upper() == key.KeyClient.DSA_ALGORITHM:
+                    pub_seq = asn1.DerSequence()
+                    pub_seq[:] = key_info.public_key
+                    recovered_key = (
+                        ("%s\n%s%s" %
+                         (DogtagKRAPlugin.DSA_PUBLIC_KEY_HEADER,
+                          pub_seq.encode().encode("base64"),
+                          DogtagKRAPlugin.DSA_PUBLIC_KEY_FOOTER)
+                         ).encode('utf-8')
+                    )
+                else:
+                    raise sstore.SecretAlgorithmNotSupportedException(
+                        key_spec.alg.upper()
+                    )
 
             elif secret_type == sstore.SecretType.PRIVATE:
                 key_data = self.keyclient.retrieve_key(key_id)
-                private_key = serialization.load_der_private_key(
-                    key_data.data,
-                    password=None,
-                    backend=default_backend()
-                )
-
-                if passphrase is not None:
-                    e_alg = serialization.BestAvailableEncryption(passphrase)
+                if key_spec.alg.upper() == key.KeyClient.RSA_ALGORITHM:
+                    recovered_key = (
+                        (RSA.importKey(key_data.data)
+                         .exportKey('PEM', passphrase, 8))
+                        .encode('utf-8')
+                    )
+                elif key_spec.alg.upper() == key.KeyClient.DSA_ALGORITHM:
+                    pub_seq = asn1.DerSequence()
+                    pub_seq[:] = key_data.data
+                    recovered_key = (
+                        ("%s\n%s%s" %
+                         (DogtagKRAPlugin.DSA_PRIVATE_KEY_HEADER,
+                          pub_seq.encode().encode("base64"),
+                          DogtagKRAPlugin.DSA_PRIVATE_KEY_FOOTER)
+                         ).encode('utf-8')
+                    )
                 else:
-                    e_alg = serialization.NoEncryption()
-
-                recovered_key = private_key.private_bytes(
-                    encoding=serialization.Encoding.PEM,
-                    format=serialization.PrivateFormat.PKCS8,
-                    encryption_algorithm=e_alg
-                )
+                    raise sstore.SecretAlgorithmNotSupportedException(
+                        key_spec.alg.upper()
+                    )
         else:
             # TODO(alee-3) send transport key as well when dogtag client API
             # changes in case the transport key has changed.
@@ -393,6 +365,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         usages = [key.SymKeyGenerationRequest.DECRYPT_USAGE,
                   key.SymKeyGenerationRequest.ENCRYPT_USAGE]
 
+        client_key_id = uuid.uuid4().hex
         algorithm = self._map_algorithm(key_spec.alg.lower())
 
         if algorithm is None:
@@ -403,27 +376,11 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
                 u._("Passphrase encryption is not supported for symmetric"
                     " key generating algorithms."))
 
-        key_id = None
-        attempts = 0
-        offset_time = 1
-        while attempts <= self.retries and key_id is None:
-            client_key_id = uuidutils.generate_uuid()
-            response = self.keyclient.generate_symmetric_key(
-                client_key_id,
-                algorithm,
-                key_spec.bit_length,
-                usages)
-            key_id = response.get_key_id()
-
-            if key_id is None:
-                LOG.warning("generate_symkey: key_id is None.  attempts: {}"
-                            .format(attempts))
-                attempts += 1
-                time.sleep(offset_time)
-                offset_time += 1
-
-        if key_id is None:
-            raise DogtagPluginGenerationException
+        response = self.keyclient.generate_symmetric_key(
+            client_key_id,
+            algorithm,
+            key_spec.bit_length,
+            usages)
 
         # Barbican expects stored keys to be base 64 encoded.  We need to
         # add flag to the keyclient.generate_symmetric_key() call above
@@ -435,6 +392,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         # key encoded data.
         return {DogtagKRAPlugin.ALG: key_spec.alg,
                 DogtagKRAPlugin.BIT_LENGTH: key_spec.bit_length,
+                DogtagKRAPlugin.SECRET_MODE: key_spec.mode,
                 DogtagKRAPlugin.KEY_ID: response.get_key_id(),
                 DogtagKRAPlugin.GENERATED: True}
 
@@ -447,7 +405,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         usages = [key.AsymKeyGenerationRequest.DECRYPT_USAGE,
                   key.AsymKeyGenerationRequest.ENCRYPT_USAGE]
 
-        client_key_id = uuidutils.generate_uuid()
+        client_key_id = uuid.uuid4().hex
         algorithm = self._map_algorithm(key_spec.alg.lower())
         passphrase = key_spec.passphrase
 
@@ -464,7 +422,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
                 )
 
             stored_passphrase_info = self.keyclient.archive_key(
-                uuidutils.generate_uuid(),
+                uuid.uuid4().hex,
                 self.keyclient.PASS_PHRASE_TYPE,
                 base64.b64encode(passphrase))
 
@@ -539,23 +497,20 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
 
         Note that only algorithms supported by Dogtag will be mapped.
         """
-        if algorithm is None:
-            return None
-
-        if algorithm.lower() == sstore.KeyAlgorithm.AES.lower():
+        if algorithm == sstore.KeyAlgorithm.AES:
             return key.KeyClient.AES_ALGORITHM
-        elif algorithm.lower() == sstore.KeyAlgorithm.DES.lower():
+        elif algorithm == sstore.KeyAlgorithm.DES:
             return key.KeyClient.DES_ALGORITHM
-        elif algorithm.lower() == sstore.KeyAlgorithm.DESEDE.lower():
+        elif algorithm == sstore.KeyAlgorithm.DESEDE:
             return key.KeyClient.DES3_ALGORITHM
-        elif algorithm.lower() == sstore.KeyAlgorithm.DSA.lower():
+        elif algorithm == sstore.KeyAlgorithm.DSA:
             return key.KeyClient.DSA_ALGORITHM
-        elif algorithm.lower() == sstore.KeyAlgorithm.RSA.lower():
+        elif algorithm == sstore.KeyAlgorithm.RSA:
             return key.KeyClient.RSA_ALGORITHM
-        elif algorithm.lower() == sstore.KeyAlgorithm.DIFFIE_HELLMAN.lower():
+        elif algorithm == sstore.KeyAlgorithm.DIFFIE_HELLMAN:
             # may be supported, needs to be tested
             return None
-        elif algorithm.lower() == sstore.KeyAlgorithm.EC.lower():
+        elif algorithm == sstore.KeyAlgorithm.EC:
             # asymmetric keys not yet supported
             return None
         else:
@@ -647,37 +602,6 @@ def _catch_enrollment_exceptions(ca_related_function):
     return _catch_enrollment_exception
 
 
-def _catch_subca_creation_exceptions(ca_related_function):
-    def _catch_subca_exception(self, *args, **kwargs):
-        try:
-            return ca_related_function(self, *args, **kwargs)
-        except pki.BadRequestException as e:
-            raise exception.BadSubCACreationRequest(reason=e.message)
-        except pki.PKIException as e:
-            raise exception.SubCACreationErrors(reason=e.message)
-        except request_exceptions.RequestException:
-            raise exception.SubCACreationErrors(
-                reason="Unable to connect to CA")
-
-    return _catch_subca_exception
-
-
-def _catch_subca_deletion_exceptions(ca_related_function):
-    def _catch_subca_exception(self, *args, **kwargs):
-        try:
-            return ca_related_function(self, *args, **kwargs)
-        except pki.ResourceNotFoundException:
-            LOG.warning("Sub-CA already deleted")
-            pass
-        except pki.PKIException as e:
-            raise exception.SubCADeletionErrors(reason=e.message)
-        except request_exceptions.RequestException:
-            raise exception.SubCACreationErrors(
-                reason="Unable to connect to CA")
-
-    return _catch_subca_exception
-
-
 class DogtagCAPlugin(cm.CertificatePluginBase):
     """Implementation of the cert plugin with Dogtag CA as the backend."""
 
@@ -689,93 +613,16 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
 
     def __init__(self, conf=CONF):
         """Constructor - create the cert clients."""
+        crypto, create_nss_db = setup_nss_db(conf, 'ca')
         connection = create_connection(conf, 'ca')
         self.certclient = pki.cert.CertClient(connection)
+
+        if crypto is not None:
+            crypto.initialize()
+
         self.simple_cmc_profile = conf.dogtag_plugin.simple_cmc_profile
         self.auto_approved_profiles = conf.dogtag_plugin.auto_approved_profiles
 
-        self.working_dir = conf.dogtag_plugin.plugin_working_dir
-        if not os.path.isdir(self.working_dir):
-            os.mkdir(self.working_dir)
-
-        self._expiration = None
-        self._expiration_delta = conf.dogtag_plugin.ca_expiration_time
-        self._expiration_data_path = os.path.join(self.working_dir,
-                                                  "expiration_data.txt")
-
-        self._host_aid_path = os.path.join(self.working_dir, "host_aid.txt")
-        self._host_aid = None
-
-        if not os.path.isfile(self._expiration_data_path):
-            self.expiration = datetime.datetime.utcnow()
-
-        global subcas_available
-        subcas_available = self._are_subcas_enabled_on_backend(connection)
-        if subcas_available:
-            self.authority_client = authority.AuthorityClient(connection)
-            if not os.path.isfile(self._host_aid_path):
-                self.host_aid = self.get_host_aid()
-
-    @property
-    def expiration(self):
-        if self._expiration is None:
-            try:
-                with open(self._expiration_data_path) as expiration_fh:
-                    self._expiration = datetime.datetime.strptime(
-                        expiration_fh.read(),
-                        "%Y-%m-%d %H:%M:%S.%f"
-                    )
-            except (ValueError, TypeError):
-                LOG.warning("Invalid data read from expiration file")
-                self.expiration = datetime.utcnow()
-        return self._expiration
-
-    @expiration.setter
-    def expiration(self, val):
-        with open(self._expiration_data_path, 'w') as expiration_fh:
-            expiration_fh.write(val.strftime("%Y-%m-%d %H:%M:%S.%f"))
-        self._expiration = val
-
-    @property
-    def host_aid(self):
-        if self._host_aid is None:
-            with open(self._host_aid_path) as host_aid_fh:
-                self._host_aid = host_aid_fh.read()
-        return self._host_aid
-
-    @host_aid.setter
-    def host_aid(self, val):
-        if val is not None:
-            with open(self._host_aid_path, 'w') as host_aid_fh:
-                host_aid_fh.write(val)
-        self._host_aid = val
-
-    def _are_subcas_enabled_on_backend(self, connection):
-        """Check if subca feature is available
-
-        SubCA creation must be supported in both the Dogtag client as well
-        as on the back-end server.  Moreover, it must be enabled on the
-        backend server.  This method sets the subcas_available global variable.
-        :return: True/False
-        """
-        global subcas_available
-        if subcas_available:
-            # subcas are supported in the Dogtag client
-            try:
-                feature_client = feature.FeatureClient(connection)
-                authority_feature = feature_client.get_feature("authority")
-                if authority_feature.enabled:
-                    LOG.info("Sub-CAs are enabled by Dogtag server")
-                    return True
-                else:
-                    LOG.info("Sub-CAs are not enabled by Dogtag server")
-            except (request_exceptions.HTTPError,
-                    pki.ResourceNotFoundException):
-                LOG.info("Sub-CAs are not supported by Dogtag server")
-        else:
-            LOG.info("Sub-CAs are not supported by Dogtag client")
-        return False
-
     def _get_request_id(self, order_id, plugin_meta, operation):
         request_id = plugin_meta.get(self.REQUEST_ID, None)
         if not request_id:
@@ -912,8 +759,8 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
         }
 
         if request_type not in jump_table:
-            raise DogtagPluginNotSupportedException(u._(
-                "Dogtag plugin does not support %s request type").format(
+            raise DogtagPluginNotSupportedException(
+                "Dogtag plugin does not support %s request type".format(
                     request_type))
 
         return jump_table[request_type](order_id, order_meta, plugin_meta,
@@ -957,8 +804,8 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
         :param barbican_meta_dto:
         :return: cm.ResultDTO
         """
-        raise DogtagPluginNotSupportedException(u._(
-            "Dogtag plugin does not support %s request type").format(
+        raise DogtagPluginNotSupportedException(
+            "Dogtag plugin does not support %s request type".format(
                 cm.CertificateRequestType.FULL_CMC_REQUEST))
 
     @_catch_enrollment_exceptions
@@ -1025,24 +872,14 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
         :param barbican_meta_dto: Extra data to aid in processing.
         :return: cm.ResultDTO
         """
-        ca_id = barbican_meta_dto.plugin_ca_id or self.get_default_ca_name()
-
         if profile_id in self.auto_approved_profiles:
-            if ca_id == self.get_default_ca_name():
-                results = self.certclient.enroll_cert(profile_id, inputs)
-            else:
-                results = self.certclient.enroll_cert(
-                    profile_id, inputs, ca_id)
+            results = self.certclient.enroll_cert(profile_id, inputs)
             return self._process_auto_enrollment_results(
                 results, plugin_meta, barbican_meta_dto)
         else:
             request = self.certclient.create_enrollment_request(
                 profile_id, inputs)
-            if ca_id == self.get_default_ca_name():
-                results = self.certclient.submit_enrollment_request(request)
-            else:
-                results = self.certclient.submit_enrollment_request(
-                    request, ca_id)
+            results = self.certclient.submit_enrollment_request(request)
             return self._process_pending_enrollment_results(
                 results, plugin_meta, barbican_meta_dto)
 
@@ -1112,22 +949,9 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
         dto = None
         if request_status == pki.cert.CertRequestStatus.COMPLETE:
             if cert is not None:
-                # Barbican is expecting base 64 encoded PEM, so we base64
-                # encode below.
-                #
-                # Currently there is an inconsistency in what Dogtag returns
-                # for certificates and intermediates.  For certs, we return
-                # PEM, whereas for intermediates, we return headerless PEM.
-                # This is being addressed in Dogtag ticket:
-                # https://fedorahosted.org/pki/ticket/1374
-                #
-                # Until this is addressed, simply add the missing headers
-                cert_chain = (CERT_HEADER + "\r\n" + cert.pkcs7_cert_chain +
-                              CERT_FOOTER)
-
                 dto = cm.ResultDTO(cm.CertificateStatus.CERTIFICATE_GENERATED,
-                                   certificate=base64.b64encode(cert.encoded),
-                                   intermediates=base64.b64encode(cert_chain))
+                                   certificate=cert.encoded,
+                                   intermediates=cert.pkcs7_cert_chain)
             else:
                 raise cm.CertificateGeneralException(
                     u._("request_id {req_id} returns COMPLETE but no cert "
@@ -1231,121 +1055,3 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
         return [cm.CertificateRequestType.SIMPLE_CMC_REQUEST,
                 cm.CertificateRequestType.STORED_KEY_REQUEST,
                 cm.CertificateRequestType.CUSTOM_REQUEST]
-
-    def supports_create_ca(self):
-        """Returns if this plugin and the backend CA supports subCAs
-
-        :return: True/False
-        """
-        return subcas_available
-
-    @_catch_subca_creation_exceptions
-    def create_ca(self, ca_create_dto):
-        """Creates a subordinate CA upon request
-
-        :param ca_create_dto:
-            Data transfer object :class:`CACreateDTO` containing data
-            required to generate a subordinate CA.  This data includes
-            the subject DN of the new CA signing certificate, a name for
-            the new CA and a reference to the CA that will issue the new
-            subordinate CA's signing certificate,
-
-        :return: ca_info:
-            Dictionary containing the data needed to create a
-            models.CertificateAuthority object
-        """
-        if not subcas_available:
-            raise exception.SubCAsNotSupported(
-                "Subordinate CAs are not supported by this Dogtag CA")
-
-        parent_ca_id = self._get_correct_ca_id(ca_create_dto.parent_ca_id)
-        ca_data = authority.AuthorityData(
-            dn=ca_create_dto.subject_dn,
-            parent_aid=parent_ca_id,
-            description=ca_create_dto.name)
-
-        new_ca_data = self.authority_client.create_ca(ca_data)
-
-        cert = self.authority_client.get_cert(new_ca_data.aid, "PEM")
-        chain = self.authority_client.get_chain(new_ca_data.aid, "PEM")
-
-        return {
-            cm.INFO_NAME: new_ca_data.description,
-            cm.INFO_CA_SIGNING_CERT: cert,
-            cm.INFO_EXPIRATION: self.expiration.isoformat(),
-            cm.INFO_INTERMEDIATES: chain,
-            cm.PLUGIN_CA_ID: new_ca_data.aid
-        }
-
-    def _get_correct_ca_id(self, plugin_ca_id):
-        """Returns the correct authority id
-
-        When the Dogtag plugin updates its CA list, any subcas will
-        have a plugin_ca_id that matches the authority_id (aid) as
-        returned from the backend CA.
-
-        For migration purposes, though, ie. migrating from a non-subca
-        environment to a subca one, we want the host CA to keep the same
-        plugin_ca_id (which is the default_ca_name) so that no disruption
-        occurs.  Therefore, we need to store the host CA's authority ID
-        (in get_ca_info) and return it here instead.
-        """
-        if plugin_ca_id == self.get_default_ca_name():
-            return self.host_aid
-        else:
-            return plugin_ca_id
-
-    @_catch_subca_deletion_exceptions
-    def delete_ca(self, ca_id):
-        """Deletes a subordinate CA
-
-        :param ca_id: id for the CA as specified by the plugin
-        :return: None
-        """
-        if not subcas_available:
-            raise exception.SubCAsNotSupported(
-                "Subordinate CAs are not supported by this Dogtag CA")
-
-        # ca must be disabled first
-        self.authority_client.disable_ca(ca_id)
-        self.authority_client.delete_ca(ca_id)
-
-    def get_ca_info(self):
-        if not subcas_available:
-            return super(DogtagCAPlugin, self).get_ca_info()
-
-        self.expiration = (datetime.datetime.utcnow() + datetime.timedelta(
-            days=int(self._expiration_delta)))
-
-        ret = {}
-        cas = self.authority_client.list_cas()
-        for ca_data in cas.ca_list:
-            if not ca_data.enabled:
-                continue
-
-            cert = self.authority_client.get_cert(ca_data.aid, "PEM")
-            chain = self.authority_client.get_chain(ca_data.aid, "PEM")
-            ca_info = {
-                cm.INFO_NAME: ca_data.description,
-                cm.INFO_CA_SIGNING_CERT: cert,
-                cm.INFO_INTERMEDIATES: chain,
-                cm.INFO_EXPIRATION: self.expiration.isoformat()
-            }
-
-            # handle the migration case.  The top level CA should continue
-            # to work as before
-
-            if ca_data.is_host_authority:
-                ret[self.get_default_ca_name()] = ca_info
-                self.host_aid = ca_data.aid
-            else:
-                ret[ca_data.aid] = ca_info
-
-        return ret
-
-    def get_host_aid(self):
-        cas = self.authority_client.list_cas()
-        for ca_data in cas.ca_list:
-            if ca_data.is_host_authority:
-                return ca_data.aid
-        return None
