@@ -19,17 +19,13 @@ from oslo_config import cfg
 import six
 from stevedore import named
 
-from barbican.common import config
 from barbican.common import exception
 from barbican.common import utils
 from barbican import i18n as u
-from barbican.plugin.util import multiple_backends
-from barbican.plugin.util import utils as plugin_utils
-
 
 _SECRET_STORE = None
 
-CONF = config.new_config()
+CONF = cfg.CONF
 DEFAULT_PLUGIN_NAMESPACE = 'barbican.secretstore.plugin'
 DEFAULT_PLUGINS = ['store_crypto']
 
@@ -43,26 +39,10 @@ store_opts = [
     cfg.MultiStrOpt('enabled_secretstore_plugins',
                     default=DEFAULT_PLUGINS,
                     help=u._('List of secret store plugins to load.')
-                    ),
-    cfg.BoolOpt('enable_multiple_secret_stores',
-                default=False,
-                help=u._('Flag to enable multiple secret store plugin'
-                         ' backend support. Default is False')
-                ),
-    cfg.ListOpt('stores_lookup_suffix',
-                help=u._('List of suffix to use for looking up plugins which '
-                         'are supported with multiple backend support.')
-                )
+                    )
 ]
 CONF.register_group(store_opt_group)
 CONF.register_opts(store_opts, group=store_opt_group)
-config.parse_args(CONF)
-
-config.set_module_config("secretstore", CONF)
-
-
-def list_opts():
-    yield store_opt_group, store_opts
 
 
 class SecretStorePluginNotFound(exception.BarbicanHTTPException):
@@ -80,34 +60,9 @@ class SecretStorePluginNotFound(exception.BarbicanHTTPException):
         super(SecretStorePluginNotFound, self).__init__(message)
 
 
-class SecretStoreSupportedPluginNotFound(exception.BarbicanHTTPException):
-    """Raised when no secret store supported plugin is found."""
-
-    client_message = u._("Secret store supported plugin not found.")
-    status_code = 400
-
-    def __init__(self, key_spec):
-        message = u._("Could not find a secret store plugin for storing "
-                      "secret with algorithm '{alg}' and bit-length "
-                      "'{len}'.").format(alg=key_spec.alg,
-                                         len=key_spec.bit_length)
-        super(SecretStoreSupportedPluginNotFound, self).__init__(
-            message)
-
-
-class SecretGenerateSupportedPluginNotFound(exception.BarbicanHTTPException):
-    """Raised when no secret generate supported plugin is found."""
-
-    client_message = u._("Secret generate supported plugin not found.")
-    status_code = 400
-
-    def __init__(self, key_spec):
-        message = u._("Could not find a secret store plugin for generating "
-                      "secret with algorithm '{alg}' and bit-length "
-                      "'{len}'.").format(alg=key_spec.alg,
-                                         len=key_spec.bit_length)
-        super(SecretGenerateSupportedPluginNotFound, self).__init__(
-            message)
+class SecretStoreSupportedPluginNotFound(exception.BarbicanException):
+    """Raised if no plugins are found that support the requested operation."""
+    message = u._("Secret store plugin not found for requested operation.")
 
 
 class SecretContentTypeNotSupportedException(exception.BarbicanHTTPException):
@@ -187,12 +142,8 @@ class SecretPayloadDecodingError(exception.BarbicanHTTPException):
         )
 
 
-class SecretAcceptNotSupportedException(exception.BarbicanHTTPException):
+class SecretAcceptNotSupportedException(exception.BarbicanException):
     """Raised when requested decrypted content-type is not available."""
-
-    client_message = u._("Wrong payload content-type")
-    status_code = 406
-
     def __init__(self, accept):
         super(SecretAcceptNotSupportedException, self).__init__(
             u._("Secret Accept of '{accept}' not supported").format(
@@ -227,20 +178,6 @@ class SecretAlgorithmNotSupportedException(exception.BarbicanHTTPException):
         self.algorithm = algorithm
 
 
-class GeneratePassphraseNotSupportedException(exception.BarbicanHTTPException):
-    """Raised when generating keys encrypted by passphrase is not supported."""
-
-    client_message = (
-        u._("Generating keys encrypted with passphrases is not supported")
-    )
-    status_code = 400
-
-    def __init__(self):
-        super(GeneratePassphraseNotSupportedException, self).__init__(
-            self.client_message
-        )
-
-
 class SecretStorePluginsNotConfigured(exception.BarbicanException):
     """Raised when there are no secret store plugins configured."""
     def __init__(self):
@@ -278,7 +215,7 @@ class SecretType(object):
     PRIVATE = "private"
     """Constant to define the passphrase type. Used by getSecret to retrieve a
     passphrase."""
-    PASSPHRASE = "passphrase"  # nosec
+    PASSPHRASE = "passphrase"
     """Constant to define the certificate type. Used by getSecret to retrieve a
     certificate."""
     CERTIFICATE = "certificate"
@@ -286,7 +223,7 @@ class SecretType(object):
     opaque data. Opaque data can be any kind of data. This data type signals to
     Barbican to just store the information and do not worry about the format or
     encoding. This is the default type if no type is specified by the user."""
-    OPAQUE = utils.SECRET_TYPE_OPAQUE
+    OPAQUE = "opaque"
 
 
 class KeyAlgorithm(object):
@@ -303,8 +240,8 @@ class KeyAlgorithm(object):
     HMACSHA1 = "hmacsha1"
     """Constant for the HMACSHA256 algorithm."""
     HMACSHA256 = "hmacsha256"
-    """Constant for the HMACSHA384 algorithm."""
-    HMACSHA384 = "hmacsha384"
+    """Constant for the HMACSHA348 algorithm."""
+    HMACSHA348 = "hmacsha348"
     """Constant for the HMACSHA512 algorithm."""
     HMACSHA512 = "hmacsha512"
     """List of asymmetric algorithms"""
@@ -317,7 +254,7 @@ class KeyAlgorithm(object):
     DESEDE = "desede"
     """List of symmetric algorithms"""
     SYMMETRIC_ALGORITHMS = [AES, DES, DESEDE, HMACSHA1,
-                            HMACSHA256, HMACSHA384, HMACSHA512]
+                            HMACSHA256, HMACSHA348, HMACSHA512]
 
 
 class KeySpec(object):
@@ -393,18 +330,6 @@ class AsymmetricKeyMetadataDTO(object):
 @six.add_metaclass(abc.ABCMeta)
 class SecretStoreBase(object):
 
-    @abc.abstractmethod
-    def get_plugin_name(self):
-        """Gets user friendly plugin name.
-
-        This plugin name is expected to be read from config file.
-        There will be a default defined for plugin name which can be customized
-        in specific deployment if needed.
-
-        This name needs to be unique across a deployment.
-        """
-        raise NotImplementedError  # pragma: no cover
-
     @abc.abstractmethod
     def generate_symmetric_key(self, key_spec):
         """Generate a new symmetric key and store it.
@@ -548,33 +473,26 @@ class SecretStoreBase(object):
 
 def _enforce_extensions_configured(plugin_related_function):
     def _check_plugins_configured(self, *args, **kwargs):
-        if not self.extensions:
+        if len(self.extensions) < 1:
             raise SecretStorePluginsNotConfigured()
         return plugin_related_function(self, *args, **kwargs)
     return _check_plugins_configured
 
 
 class SecretStorePluginManager(named.NamedExtensionManager):
-    def __init__(self, conf=CONF, invoke_args=(), invoke_kwargs={}):
-        ss_conf = config.get_module_config('secretstore')
-        plugin_names = self._get_internal_plugin_names(ss_conf)
-
+    def __init__(self, conf=CONF, invoke_on_load=True,
+                 invoke_args=(), invoke_kwargs={}):
         super(SecretStorePluginManager, self).__init__(
-            ss_conf.secretstore.namespace,
-            plugin_names,
-            invoke_on_load=False,  # Defer creating plugins to utility below.
+            conf.secretstore.namespace,
+            conf.secretstore.enabled_secretstore_plugins,
+            invoke_on_load=invoke_on_load,
             invoke_args=invoke_args,
-            invoke_kwds=invoke_kwargs,
-            name_order=True  # extensions sorted as per order of plugin names
+            invoke_kwds=invoke_kwargs
         )
 
-        plugin_utils.instantiate_plugins(self, invoke_args, invoke_kwargs)
-
-        multiple_backends.sync_secret_stores(self)
-
     @_enforce_extensions_configured
     def get_plugin_store(self, key_spec, plugin_name=None,
-                         transport_key_needed=False, project_id=None):
+                         transport_key_needed=False):
         """Gets a secret store plugin.
 
         :param: plugin_name: set to plugin_name to get specific plugin
@@ -583,27 +501,25 @@ class SecretStorePluginManager(named.NamedExtensionManager):
         key is required.
         :returns: SecretStoreBase plugin implementation
         """
-        active_plugins = multiple_backends.get_applicable_store_plugins(
-            self, project_id=project_id, existing_plugin_name=plugin_name)
 
         if plugin_name is not None:
-            for plugin in active_plugins:
-                if utils.generate_fullname_for(plugin) == plugin_name:
-                    return plugin
+            for ext in self.extensions:
+                if utils.generate_fullname_for(ext.obj) == plugin_name:
+                    return ext.obj
             raise SecretStorePluginNotFound(plugin_name)
 
         if not transport_key_needed:
-            for plugin in active_plugins:
-                if plugin.store_secret_supports(key_spec):
-                    return plugin
+            for ext in self.extensions:
+                if ext.obj.store_secret_supports(key_spec):
+                    return ext.obj
 
         else:
-            for plugin in active_plugins:
-                if (plugin.get_transport_key() is not None and
-                        plugin.store_secret_supports(key_spec)):
-                    return plugin
+            for ext in self.extensions:
+                if (ext.obj.get_transport_key() is not None and
+                        ext.obj.store_secret_supports(key_spec)):
+                    return ext.obj
 
-        raise SecretStoreSupportedPluginNotFound(key_spec)
+        raise SecretStoreSupportedPluginNotFound()
 
     @_enforce_extensions_configured
     def get_plugin_retrieve_delete(self, plugin_name):
@@ -621,13 +537,13 @@ class SecretStorePluginManager(named.NamedExtensionManager):
                  configured on the database side.
         """
 
-        for plugin in plugin_utils.get_active_plugins(self):
-            if utils.generate_fullname_for(plugin) == plugin_name:
-                return plugin
+        for ext in self.extensions:
+            if utils.generate_fullname_for(ext.obj) == plugin_name:
+                return ext.obj
         raise StorePluginNotAvailableOrMisconfigured(plugin_name)
 
     @_enforce_extensions_configured
-    def get_plugin_generate(self, key_spec, project_id=None):
+    def get_plugin_generate(self, key_spec):
         """Gets a secret generate plugin.
 
         :param key_spec: KeySpec that contains details on the type of key to
@@ -635,32 +551,10 @@ class SecretStorePluginManager(named.NamedExtensionManager):
         :returns: SecretStoreBase plugin implementation
         """
 
-        active_plugins = multiple_backends.get_applicable_store_plugins(
-            self, project_id=project_id, existing_plugin_name=None)
-
-        for plugin in active_plugins:
-            if plugin.generate_supports(key_spec):
-                return plugin
-        raise SecretGenerateSupportedPluginNotFound(key_spec)
-
-    def _get_internal_plugin_names(self, secretstore_conf):
-        """Gets plugin names used for loading via stevedore.
-
-        When multiple secret store support is enabled, then secret store plugin
-        names are read via updated configuration structure. If not enabled,
-        then it reads MultiStr property in 'secretstore' config section.
-        """
-        # to cache default global secret store value on first use
-        self.global_default_store_dict = None
-        if utils.is_multiple_backends_enabled():
-            self.parsed_stores = multiple_backends.\
-                read_multiple_backends_config()
-            plugin_names = [store.store_plugin for store in self.parsed_stores
-                            if store.store_plugin]
-        else:
-            plugin_names = secretstore_conf.secretstore.\
-                enabled_secretstore_plugins
-        return plugin_names
+        for ext in self.extensions:
+            if ext.obj.generate_supports(key_spec):
+                return ext.obj
+        raise SecretStoreSupportedPluginNotFound()
 
 
 def get_manager():
