@@ -16,12 +16,12 @@
 """
 Barbican certificate processing plugins and support.
 """
-from oslo.config import cfg
+from oslo_config import cfg
 from requests import exceptions as request_exceptions
 from symantecssl.core import Symantec
 from symantecssl import exceptions as symantec_exceptions
 
-from barbican.openstack.common import gettextutils as u
+from barbican import i18n as u
 from barbican.plugin.interface import certificate_manager as cert
 
 CONF = cfg.CONF
@@ -47,18 +47,31 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
 
     def __init__(self, conf=CONF):
         self.username = conf.symantec_plugin.username
+        self.password = conf.symantec_plugin.password
+        self.url = conf.symantec_plugin.url
+
         if self.username == None:
             raise ValueError(u._("username is required"))
 
-        self.password = conf.symantec_plugin.password
         if self.password == None:
             raise ValueError(u._("password is required"))
 
-        self.url = conf.symantec_plugin.url
         if self.url == None:
             raise ValueError(u._("url is required"))
 
-    def issue_certificate_request(self, order_id, order_meta, plugin_meta):
+    def get_default_ca_name(self):
+        return "Symantec CA"
+
+    def get_default_signing_cert(self):
+        # TODO(chellygel) Add code to get the signing cert
+        return None
+
+    def get_default_intermediates(self):
+        # TODO(chellygel) Add code to get the cert chain
+        return None
+
+    def issue_certificate_request(self, order_id, order_meta, plugin_meta,
+                                  barbican_meta_dto):
         """Create the initial order with CA
 
         :param order_id: ID associated with the order
@@ -67,23 +80,25 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
                             this plugin. Plugins may also update/add
                             information here which Barbican will persist
                             on their behalf.
+        :param barbican_meta_dto: additional data needed to process order.
         :returns: ResultDTO
         """
         successful, error_msg, can_retry = _ca_create_order(order_meta,
                                                             plugin_meta)
 
-        if successful:
-            return cert.ResultDTO(cert.CertificateStatus.WAITING_FOR_CA)
-        elif can_retry:
-            return cert.ResultDTO(
-                cert.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
-                status_message=error_msg
-            )
-        else:
-            return cert.ResultDTO(cert.CertificateStatus.
-                                  CA_UNAVAILABLE_FOR_REQUEST)
+        status = cert.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST
+        message = None
 
-    def modify_certificate_request(self, order_id, order_meta, plugin_meta):
+        if successful:
+            status = cert.CertificateStatus.WAITING_FOR_CA
+        elif can_retry:
+            status = cert.CertificateStatus.CLIENT_DATA_ISSUE_SEEN
+            message = error_msg
+
+        return cert.ResultDTO(status=status, status_message=message)
+
+    def modify_certificate_request(self, order_id, order_meta, plugin_meta,
+                                   barbican_meta_dto):
         """Update the order meta-data
 
         :param order_id: ID associated with the order
@@ -92,10 +107,12 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
                             this plugin. Plugins may also update/add
                             information here which Barbican will persist
                             on their behalf.
+        :param barbican_meta_dto: additional data needed to process order.
         """
         raise NotImplementedError  # pragma: no cover
 
-    def cancel_certificate_request(self, order_id, order_meta, plugin_meta):
+    def cancel_certificate_request(self, order_id, order_meta, plugin_meta,
+                                   barbican_meta_dto):
         """Cancel the order
 
         :param order_id: ID associated with the order
@@ -104,10 +121,12 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
                             this plugin. Plugins may also update/add
                             information here which Barbican will persist
                             on their behalf.
+        :param barbican_meta_dto: additional data needed to process order.
         """
         raise NotImplementedError  # pragma: no cover
 
-    def check_certificate_status(self, order_id, order_meta, plugin_meta):
+    def check_certificate_status(self, order_id, order_meta, plugin_meta,
+                                 barbican_meta_dto):
         """Check status of the order
 
         :param order_id: ID associated with the order
@@ -116,6 +135,7 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
                             this plugin. Plugins may also update/add
                             information here which Barbican will persist
                             on their behalf.
+        :param barbican_meta_dto: additional data needed to process order.
         """
         raise NotImplementedError  # pragma: no cover
 
