@@ -16,15 +16,13 @@ import os
 import uuid
 
 import mock
+import testtools
 
 from barbican.common import resources
 from barbican.model import models
 from barbican.model import repositories
-from barbican.tests.api.controllers import test_acls
-from barbican.tests.api import test_resources_policy as test_policy
 from barbican.tests import utils
 
-
 order_repo = repositories.get_order_repository()
 project_repo = repositories.get_project_repository()
 ca_repo = repositories.get_ca_repository()
@@ -48,7 +46,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             order_type='key',
             meta=generic_key_meta
         )
-        self.assertEqual(202, resp.status_int)
+        self.assertEqual(resp.status_int, 202)
 
         # Make sure we get a valid uuid for the order
         uuid.UUID(order_uuid)
@@ -68,7 +66,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             meta=meta
         )
 
-        self.assertEqual(202, resp.status_int)
+        self.assertEqual(resp.status_int, 202)
 
     def test_order_creation_should_fail_without_a_type(self):
         resp, _ = create_order(
@@ -77,7 +75,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             expect_errors=True
         )
 
-        self.assertEqual(400, resp.status_int)
+        self.assertEqual(resp.status_int, 400)
 
     def test_order_creation_should_fail_without_metadata(self):
         resp, _ = create_order(
@@ -86,7 +84,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             expect_errors=True
         )
 
-        self.assertEqual(400, resp.status_int)
+        self.assertEqual(resp.status_int, 400)
 
     def test_order_create_should_fail_w_unsupported_payload_content_type(self):
         meta = {
@@ -101,7 +99,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             expect_errors=True
         )
 
-        self.assertEqual(400, resp.status_int)
+        self.assertEqual(resp.status_int, 400)
 
     def test_order_creation_should_fail_with_bogus_content(self):
         resp = self.app.post(
@@ -110,7 +108,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             headers={'Content-Type': 'application/json'},
             expect_errors=True
         )
-        self.assertEqual(400, resp.status_int)
+        self.assertEqual(resp.status_int, 400)
 
     def test_order_creation_should_fail_with_empty_dict(self):
         resp = self.app.post_json(
@@ -119,7 +117,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             headers={'Content-Type': 'application/json'},
             expect_errors=True
         )
-        self.assertEqual(400, resp.status_int)
+        self.assertEqual(resp.status_int, 400)
 
     def test_order_creation_should_fail_without_content_type_header(self):
         resp = self.app.post(
@@ -127,7 +125,7 @@ class WhenCreatingOrdersUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             'doesn\'t matter. headers are validated first',
             expect_errors=True,
         )
-        self.assertEqual(415, resp.status_int)
+        self.assertEqual(resp.status_int, 415)
 
 
 class WhenGettingOrdersListUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
@@ -138,7 +136,7 @@ class WhenGettingOrdersListUsingOrdersResource(utils.BarbicanAPIBaseTestCase):
             order_type='key',
             meta=generic_key_meta
         )
-        self.assertEqual(202, resp.status_int)
+        self.assertEqual(resp.status_int, 202)
 
         # Get the list of orders
         resp = self.app.get(
@@ -196,13 +194,6 @@ class WhenGettingOrDeletingOrders(utils.BarbicanAPIBaseTestCase):
         )
         self.assertEqual(404, resp.status_int)
 
-    def test_returns_404_on_get_with_bad_uuid(self):
-        resp = self.app.get(
-            '/orders/98c876d9-aaac-44e4-8ea8-441932962b05X',
-            expect_errors=True
-        )
-        self.assertEqual(404, resp.status_int)
-
     def test_delete_call_on_non_existant_order_should_give_404(self):
         bogus_uuid = uuid.uuid4()
         resp = self.app.delete(
@@ -316,7 +307,7 @@ class WhenCreatingOrders(utils.BarbicanAPIBaseTestCase):
         order = order_repo.get(order_uuid, self.project_id)
         self.assertIsInstance(order, models.Order)
         self.assertEqual('key', order.type)
-        self.assertEqual(order_meta, order.meta)
+        self.assertEqual(order.meta, order_meta)
 
     def test_should_return_400_when_creating_with_empty_json(self):
         resp = self.app.post_json('/orders/', {}, expect_errors=True)
@@ -351,21 +342,6 @@ class WhenCreatingCertificateOrders(utils.BarbicanAPIBaseTestCase):
             ca_model = models.CertificateAuthority(ca_information)
             ca = ca_repo.create_from(ca_model)
             self.available_ca_ids.append(ca.id)
-
-        foreign_project = resources.get_or_create_project('foreign_project')
-        foreign_ca_information = {
-            'project_id': foreign_project.id,
-            'plugin_name': 'plugin_name',
-            'plugin_ca_id': 'plugin_name ca_id1',
-            'name': 'plugin name',
-            'description': 'Master CA for default plugin',
-            'ca_signing_certificate': 'XXXXX',
-            'intermediates': 'YYYYY'
-        }
-        foreign_ca_model = models.CertificateAuthority(foreign_ca_information)
-        foreign_ca = ca_repo.create_from(foreign_ca_model)
-        self.foreign_ca_id = foreign_ca.id
-
         repositories.commit()
 
     def test_can_create_new_cert_order(self):
@@ -450,27 +426,13 @@ class WhenCreatingCertificateOrders(utils.BarbicanAPIBaseTestCase):
         )
         self.assertEqual(403, create_resp.status_int)
 
-    def test_create_with_wrong_projects_subca_should_fail(self):
-        self.certificate_meta['ca_id'] = self.foreign_ca_id
 
-        create_resp, order_uuid = create_order(
-            self.app,
-            order_type='certificate',
-            meta=self.certificate_meta,
-            expect_errors=True
-        )
-        self.assertEqual(403, create_resp.status_int)
-        self.assertIn("not owned", create_resp.json['description'])
-
-
-class WhenCreatingStoredKeyOrders(utils.BarbicanAPIBaseTestCase,
-                                  test_policy.BaseTestCase):
+class WhenCreatingStoredKeyOrders(utils.BarbicanAPIBaseTestCase):
     def setUp(self):
         super(WhenCreatingStoredKeyOrders, self).setUp()
 
         # Make sure we have a project
         self.project = resources.get_or_create_project(self.project_id)
-        self.creator_user_id = 'creatorUserId'
 
     def test_can_create_new_stored_key_order(self):
         container_name = 'rsa container name'
@@ -497,175 +459,6 @@ class WhenCreatingStoredKeyOrders(utils.BarbicanAPIBaseTestCase,
         order = order_repo.get(order_uuid, self.project_id)
         self.assertIsInstance(order, models.Order)
 
-    def _setup_acl_order_context_and_create_order(
-        self, add_acls=False, read_project_access=True, order_roles=None,
-            order_user=None, expect_errors=False):
-        """Helper method to setup acls, order context and return created order.
-
-        Create order uses actual oslo policy enforcer instead of being None.
-        Create ACLs for container if 'add_acls' is True.
-        Make container private when 'read_project_access' is False.
-        """
-
-        container_name = 'rsa container name'
-        container_type = 'rsa'
-        secret_refs = []
-        self.app.extra_environ = {
-            'barbican.context': self._build_context(self.project_id,
-                                                    user=self.creator_user_id)
-        }
-        _, container_id = create_container(
-            self.app,
-            name=container_name,
-            container_type=container_type,
-            secret_refs=secret_refs
-        )
-
-        if add_acls:
-            test_acls.manage_acls(
-                self.app, 'containers', container_id,
-                read_user_ids=['u1', 'u3', 'u4'],
-                read_project_access=read_project_access,
-                is_update=False)
-
-        self.app.extra_environ = {
-            'barbican.context': self._build_context(
-                self.project_id, roles=order_roles, user=order_user,
-                is_admin=False, policy_enforcer=self.policy_enforcer)
-        }
-
-        stored_key_meta = {
-            'request_type': 'stored-key',
-            'subject_dn': 'cn=barbican-server,o=example.com',
-            'container_ref': 'https://localhost/v1/containers/' + container_id
-        }
-        return create_order(
-            self.app,
-            order_type='certificate',
-            meta=stored_key_meta,
-            expect_errors=expect_errors
-        )
-
-    def test_can_create_new_stored_key_order_no_acls_and_policy_check(self):
-        """Create stored key order with actual policy enforcement logic.
-
-        Order can be created as long as order project and user roles are
-        allowed in policy. In the test, user requesting order has container
-        project and has 'creator' role. Order should be created regardless
-        of what user id is.
-        """
-
-        create_resp, order_id = self._setup_acl_order_context_and_create_order(
-            add_acls=False, read_project_access=True, order_roles=['creator'],
-            order_user='anyUserId', expect_errors=False)
-
-        self.assertEqual(202, create_resp.status_int)
-
-        order = order_repo.get(order_id, self.project_id)
-        self.assertIsInstance(order, models.Order)
-        self.assertEqual('anyUserId', order.creator_id)
-
-    def test_should_fail_for_user_observer_role_no_acls_and_policy_check(self):
-        """Should not allow create order when user doesn't have necessary role.
-
-        Order can be created as long as order project and user roles are
-        allowed in policy. In the test, user requesting order has container
-        project but has 'observer' role. Create order should fail as expected
-        role is 'admin' or 'creator'.
-        """
-
-        create_resp, _ = self._setup_acl_order_context_and_create_order(
-            add_acls=False, read_project_access=True, order_roles=['observer'],
-            order_user='anyUserId', expect_errors=True)
-        self.assertEqual(403, create_resp.status_int)
-
-    def test_can_create_order_with_private_container_and_creator_user(self):
-        """Create order using private container with creator user.
-
-        Container has been marked private via ACLs. Still creator of container
-        should be able to create stored key order using that container
-        successfully.
-        """
-        create_resp, order_id = self._setup_acl_order_context_and_create_order(
-            add_acls=True, read_project_access=False, order_roles=['creator'],
-            order_user=self.creator_user_id, expect_errors=False)
-
-        self.assertEqual(202, create_resp.status_int)
-
-        order = order_repo.get(order_id, self.project_id)
-        self.assertIsInstance(order, models.Order)
-        self.assertEqual(self.creator_user_id, order.creator_id)
-
-    def test_can_create_order_with_private_container_and_acl_user(self):
-        """Create order using private container with acl user.
-
-        Container has been marked private via ACLs. So *generally* project user
-        should not be able to create stored key order using that container.
-        But here it can create order as that user is defined in read ACL user
-        list. Here project user means user which has 'creator' role in the
-        container project. Order project is same as container.
-        """
-
-        create_resp, order_id = self._setup_acl_order_context_and_create_order(
-            add_acls=True, read_project_access=False, order_roles=['creator'],
-            order_user='u3', expect_errors=False)
-        self.assertEqual(202, create_resp.status_int)
-
-        order = order_repo.get(order_id, self.project_id)
-        self.assertIsInstance(order, models.Order)
-        self.assertEqual('u3', order.creator_id)
-
-    def test_should_raise_with_private_container_and_project_user(self):
-        """Create order should fail using private container for project user.
-
-        Container has been marked private via ACLs. So project user should not
-        be able to create stored key order using that container. Here project
-        user means user which has 'creator' role in the container project.
-        Order project is same as container. If container was not marked
-        private, this user would have been able to create order. See next test.
-        """
-
-        create_resp, _ = self._setup_acl_order_context_and_create_order(
-            add_acls=True, read_project_access=False, order_roles=['creator'],
-            order_user='anyProjectUser', expect_errors=True)
-
-        self.assertEqual(403, create_resp.status_int)
-
-    def test_can_create_order_with_non_private_acls_and_project_user(self):
-        """Create order using non-private container with project user.
-
-        Container has not been marked private via ACLs. So project user should
-        be able to create stored key order using that container successfully.
-        Here project user means user which has 'creator' role in the container
-        project. Order project is same as container.
-        """
-        create_resp, order_id = self._setup_acl_order_context_and_create_order(
-            add_acls=True, read_project_access=True, order_roles=['creator'],
-            order_user='anyProjectUser', expect_errors=False)
-
-        self.assertEqual(202, create_resp.status_int)
-
-        order = order_repo.get(order_id, self.project_id)
-        self.assertIsInstance(order, models.Order)
-        self.assertEqual('anyProjectUser', order.creator_id)
-
-    def test_can_create_order_with_non_private_acls_and_creator_user(self):
-        """Create order using non-private container with creator user.
-
-        Container has not been marked private via ACLs. So user who created
-        container should be able to create stored key order using that
-        container successfully. Order project is same as container.
-        """
-        create_resp, order_id = self._setup_acl_order_context_and_create_order(
-            add_acls=True, read_project_access=True, order_roles=['creator'],
-            order_user=self.creator_user_id, expect_errors=False)
-
-        self.assertEqual(202, create_resp.status_int)
-
-        order = order_repo.get(order_id, self.project_id)
-        self.assertIsInstance(order, models.Order)
-        self.assertEqual(self.creator_user_id, order.creator_id)
-
     def test_should_raise_with_bad_container_ref(self):
         stored_key_meta = {
             'request_type': 'stored-key',
@@ -717,6 +510,7 @@ class WhenCreatingStoredKeyOrders(utils.BarbicanAPIBaseTestCase,
         )
         self.assertEqual(400, create_resp.status_int)
 
+    @testtools.skip("TODO(dave) Not yet implemented")
     def test_should_raise_with_container_no_access(self):
         stored_key_meta = {
             'request_type': 'stored-key',
@@ -782,7 +576,7 @@ def create_order(app, order_type=None, meta=None, expect_errors=False):
         order_ref = resp.json.get('order_ref', '')
         _, created_uuid = os.path.split(order_ref)
 
-    return resp, created_uuid
+    return (resp, created_uuid)
 
 
 def create_container(app, name=None, container_type=None, secret_refs=None,
@@ -807,4 +601,4 @@ def create_container(app, name=None, container_type=None, secret_refs=None,
         container_ref = resp.json.get('container_ref', '')
         _, created_uuid = os.path.split(container_ref)
 
-    return resp, created_uuid
+    return (resp, created_uuid)
