@@ -14,14 +14,13 @@
 # limitations under the License.
 import base64
 import os
-from unittest import mock
 
-from oslo_utils import timeutils
+import mock
 
-from barbican.api.controllers import secrets
 from barbican.common import validators
 from barbican.model import models
 from barbican.model import repositories
+from barbican.openstack.common import timeutils
 from barbican.tests import utils
 
 project_repo = repositories.get_project_repository()
@@ -35,7 +34,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
     def test_can_create_new_secret_one_step(self):
         resp, secret_uuid = create_secret(
             self.app,
-            payload='not-encrypted',
+            payload=b'not-encrypted',
             content_type='text/plain'
         )
 
@@ -47,8 +46,8 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(201, resp.status_int)
 
         secret = secrets_repo.get(secret_uuid, self.project_id)
-        self.assertEqual('test', secret.name)
-        self.assertEqual([], secret.encrypted_data)
+        self.assertEqual(secret.name, 'test')
+        self.assertEqual(secret.encrypted_data, [])
 
     def test_can_create_new_secret_if_project_doesnt_exist(self):
         # Build new context
@@ -64,7 +63,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         self.assertIsNotNone(project)
 
     def test_can_create_new_secret_with_payload_just_under_max(self):
-        large_payload = 'A' * (validators.DEFAULT_MAX_SECRET_BYTES - 8)
+        large_payload = b'A' * (validators.DEFAULT_MAX_SECRET_BYTES - 8)
         resp, _ = create_secret(
             self.app,
             payload=large_payload,
@@ -74,7 +73,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(201, resp.status_int)
 
     def test_creating_new_secret_with_oversized_payload_should_fail(self):
-        oversized_payload = 'A' * (validators.DEFAULT_MAX_SECRET_BYTES + 10)
+        oversized_payload = b'A' * (validators.DEFAULT_MAX_SECRET_BYTES + 10)
         resp, _ = create_secret(
             self.app,
             payload=oversized_payload,
@@ -106,7 +105,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         local_datetime = timeutils.parse_isotime(target_expiration)
         datetime_utc = timeutils.normalize_time(local_datetime)
 
-        self.assertEqual(datetime_utc, secret.expiration)
+        self.assertEqual(secret.expiration, datetime_utc)
 
     @mock.patch('barbican.plugin.resources.store_secret')
     def test_can_create_new_secret_meta_w_transport_key(self, mocked_store):
@@ -141,7 +140,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         # Create a normal secret with the TransportKey
         resp, secret_uuid = create_secret(
             self.app,
-            payload='not-encrypted',
+            payload=b'not-encrypted',
             content_type='text/plain',
             transport_key_id=transport_key_id
         )
@@ -158,21 +157,10 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
             transport_key_needed=False
         )
 
-    def test_new_secret_fails_with_invalid_transport_key_ref(self):
-        resp, _ = create_secret(
-            self.app,
-            payload='superdupersecret',
-            content_type='text/plain',
-            transport_key_id="non_existing_transport_key_id",
-            transport_key_needed="true",
-            expect_errors=True
-        )
-        self.assertEqual(400, resp.status_int)
-
     def test_new_secret_w_unsupported_content_type_should_fail(self):
         resp, _ = create_secret(
             self.app,
-            payload='something_here',
+            payload=b'something_here',
             content_type='bogus_content_type',
             expect_errors=True
         )
@@ -187,7 +175,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
                                                       content_type=None):
         resp, _ = create_secret(
             self.app,
-            payload='lOtfqHaUUpe6NqLABgquYQ==',
+            payload=b'lOtfqHaUUpe6NqLABgquYQ==',
             content_type=content_type,
             content_encoding=encoding,
             expect_errors=True
@@ -214,7 +202,7 @@ class WhenGettingSecretsList(utils.BarbicanAPIBaseTestCase):
             name='secret mission'
         )
 
-        self.assertEqual(201, create_resp.status_int)
+        self.assertEqual(create_resp.status_int, 201)
 
         params = {'name': 'secret mission'}
 
@@ -222,9 +210,9 @@ class WhenGettingSecretsList(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(200, get_resp.status_int)
         secret_list = get_resp.json.get('secrets')
-        self.assertEqual('secret mission', secret_list[0].get('name'))
+        self.assertEqual(secret_list[0].get('name'), 'secret mission')
 
-    def _test_list_secrets(self):
+    def test_list_secrets(self):
         # Creating a secret to be retrieved later
         create_resp, _ = create_secret(
             self.app,
@@ -240,17 +228,6 @@ class WhenGettingSecretsList(utils.BarbicanAPIBaseTestCase):
         secret_list = get_resp.json.get('secrets')
         self.assertGreater(len(secret_list), 0)
 
-        return secret_list
-
-    def test_list_secrets_v0(self):
-        secret_list = self._test_list_secrets()
-        self.assertNotIn('consumers', secret_list[0])
-
-    def test_list_secrets_v1(self):
-        utils.set_version(self.app, '1.1')
-        secret_list = self._test_list_secrets()
-        self.assertIn('consumers', secret_list[0])
-
     def test_pagination_attributes(self):
         # Create a list of secrets greater than default limit (10)
         for _ in range(11):
@@ -277,22 +254,12 @@ class WhenGettingSecretsList(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(200, get_resp.status_int)
 
         secret_list = get_resp.json.get('secrets')
-        self.assertEqual(0, len(secret_list))
+        self.assertEqual(len(secret_list), 0)
 
         # These should never exist in this scenario
         self.assertNotIn('previous', get_resp.json)
         self.assertNotIn('next', get_resp.json)
 
-    def test_bad_date_filter_results_in_400(self):
-        params = {'expiration': 'bogus'}
-        get_resp = self.app.get('/secrets/', params, expect_errors=True)
-        self.assertEqual(400, get_resp.status_int)
-
-    def test_bad_sorting_results_in_400(self):
-        params = {'sort': 'bogus'}
-        get_resp = self.app.get('/secrets/', params, expect_errors=True)
-        self.assertEqual(400, get_resp.status_int)
-
 
 class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
@@ -311,58 +278,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
             '/secrets/{0}'.format(secret_uuid), headers=headers
         )
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body.decode('utf-8'))
-
-    def test_get_secret_payload_with_pecan_default_accept_header(self):
-        payload = 'a very interesting string'
-        resp, secret_uuid = create_secret(
-            self.app,
-            payload=payload,
-            content_type='text/plain'
-        )
-
-        self.assertEqual(201, resp.status_int)
-
-        headers = {'Accept': '*/*'}
-        get_resp = self.app.get(
-            '/secrets/{0}/payload'.format(secret_uuid), headers=headers
-        )
-        self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body.decode('utf-8'))
-
-    def test_get_secret_payload_with_blank_accept_header(self):
-        payload = 'a very interesting string'
-        resp, secret_uuid = create_secret(
-            self.app,
-            payload=payload,
-            content_type='text/plain'
-        )
-
-        self.assertEqual(201, resp.status_int)
-
-        headers = {'Accept': ''}
-        get_resp = self.app.get(
-            '/secrets/{0}/payload'.format(secret_uuid), headers=headers
-        )
-        self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body.decode('utf-8'))
-
-    def test_get_secret_payload_with_no_accept_header(self):
-        payload = 'a very interesting string'
-        resp, secret_uuid = create_secret(
-            self.app,
-            payload=payload,
-            content_type='text/plain'
-        )
-
-        self.assertEqual(201, resp.status_int)
-
-        headers = {}
-        get_resp = self.app.get(
-            '/secrets/{0}/payload'.format(secret_uuid), headers=headers
-        )
-        self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body.decode('utf-8'))
+        self.assertEqual(payload, get_resp.body)
 
     def test_get_secret_is_decoded_for_binary(self):
         payload = 'a123'
@@ -378,46 +294,17 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         get_resp = self.app.get(
             '/secrets/{0}'.format(secret_uuid), headers=headers
         )
-        decoded = b'k]\xb7'
+        decoded = 'k]\xb7'
 
-        self.assertEqual(decoded, get_resp.body)
+        self.assertEqual(get_resp.body, decoded)
 
     def test_returns_404_on_get_when_not_found(self):
-        """Test with valid uuid which is not present in DB."""
         get_resp = self.app.get(
-            '/secrets/{0}'.format(utils.generate_test_valid_uuid()),
+            '/secrets/98c876d9-aaac-44e4-8ea8-441932962b05',
             headers={'Accept': 'application/json'},
             expect_errors=True
         )
-        self.assertEqual(404, get_resp.status_int)
 
-    def test_returns_404_on_get_invalid_secret_id(self):
-        """Test where uuid provided is not valid."""
-        get_resp = self.app.get(
-            '/secrets/98c876d9-aaac-44e4-8ea8-invalid-id',
-            headers={'Accept': 'application/json'},
-            expect_errors=True
-        )
-        self.assertEqual(404, get_resp.status_int)
-
-    def test_returns_404_on_get_payload_when_no_payload(self):
-        resp, secret_uuid = create_secret(self.app)
-        headers = {
-            'Accept': 'text/plain',
-        }
-        get_resp = self.app.get(
-            '/secrets/{0}/payload'.format(secret_uuid),
-            headers=headers,
-            expect_errors=True
-        )
-        self.assertEqual(404, get_resp.status_int)
-
-    def test_returns_404_on_get_with_bad_uuid(self):
-        get_resp = self.app.get(
-            '/secrets/98c876d9-aaac-44e4-8ea8-441932962b05X',
-            headers={'Accept': 'application/json'},
-            expect_errors=True
-        )
         self.assertEqual(404, get_resp.status_int)
 
     def test_returns_406_with_get_bad_accept_header(self):
@@ -460,7 +347,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         )
 
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(message, get_resp.body.decode('utf-8'))
+        self.assertEqual(message, get_resp.body)
 
     def test_put_binary_secret(self):
         resp, secret_uuid = create_secret(
@@ -493,7 +380,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        payload = base64.b64encode(b'I had something for this')
+        payload = base64.b64encode('I had something for this')
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             payload,
@@ -523,7 +410,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        payload = base64.b64encode(b'I had something for this')
+        payload = base64.b64encode('I had something for this')
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             payload,
@@ -639,7 +526,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        text_too_big = 'x' * 20050
+        text_too_big = 'x' * 10050
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             text_too_big,
@@ -669,7 +556,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         )
 
         self.assertEqual(404, delete_resp.status_int)
-        self.assertEqual('application/json', delete_resp.content_type)
+        self.assertEqual(delete_resp.content_type, 'application/json')
 
     def test_delete_with_json_accept_header(self):
         resp, secret_uuid = create_secret(
@@ -748,94 +635,6 @@ class WhenPerformingUnallowedOperations(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(405, resp.status_int)
 
 
-class WhenValidatingDateFilters(utils.BarbicanAPIBaseTestCase):
-
-    def setUp(self):
-        super(WhenValidatingDateFilters, self).setUp()
-        self.controller = secrets.SecretsController()
-
-    def test_validates_plain_timestamp(self):
-        date_filter = '2016-01-01T00:00:00'
-        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validates_gt_and_lt_timestamps(self):
-        date_filter = 'gt:2016-01-01T00:00:00,lt:2016-12-31T00:00:00'
-        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validates_gte_and_lte_timestamps(self):
-        date_filter = 'gte:2016-01-01T00:00:00,lte:2016-12-31T00:00:00'
-        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_two_plain_timestamps(self):
-        date_filter = '2016-01-01T00:00:00,2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_two_gt_timestamps(self):
-        date_filter = 'gt:2016-01-01T00:00:00,gt:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_two_lt_timestamps(self):
-        date_filter = 'lt:2016-01-01T00:00:00,lt:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_two_gte_timestamps(self):
-        date_filter = 'gte:2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_two_lte_timestamps(self):
-        date_filter = 'lte:2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_plain_and_gte_timestamps(self):
-        date_filter = '2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-        date_filter = 'gte:2016-01-01T00:00:00,2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_plain_and_lte_timestamps(self):
-        date_filter = '2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-        date_filter = 'lte:2016-01-01T00:00:00,2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_gt_and_gte_timestamps(self):
-        date_filter = 'gt:2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_lt_and_lte_timestamps(self):
-        date_filter = 'lt:2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-    def test_validation_fails_with_bogus_timestamp(self):
-        date_filter = 'bogus'
-        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
-
-
-class WhenValidatingSortFilters(utils.BarbicanAPIBaseTestCase):
-
-    def setUp(self):
-        super(WhenValidatingSortFilters, self).setUp()
-        self.controller = secrets.SecretsController()
-
-    def test_validates_name_sorting(self):
-        sorting = 'name'
-        self.assertTrue(self.controller._is_valid_sorting(sorting))
-
-    def test_validation_fails_for_bogus_attribute(self):
-        sorting = 'bogus'
-        self.assertFalse(self.controller._is_valid_sorting(sorting))
-
-    def test_validation_fails_for_duplicate_keys(self):
-        sorting = 'name,name:asc'
-        self.assertFalse(self.controller._is_valid_sorting(sorting))
-
-    def test_validation_fails_for_too_many_colons(self):
-        sorting = 'name:asc:foo'
-        self.assertFalse(self.controller._is_valid_sorting(sorting))
-
-
 # ----------------------- Helper Functions ---------------------------
 def create_secret(app, name=None, algorithm=None, bit_length=None, mode=None,
                   expiration=None, payload=None, content_type=None,
@@ -870,4 +669,4 @@ def create_secret(app, name=None, algorithm=None, bit_length=None, mode=None,
         secret_ref = resp.json.get('secret_ref', '')
         _, created_uuid = os.path.split(secret_ref)
 
-    return resp, created_uuid
+    return (resp, created_uuid)
