@@ -15,7 +15,8 @@
 import datetime
 import time
 
-from barbican.common import config
+from oslo_config import cfg
+
 from barbican.common import exception
 from barbican.model import models
 from barbican.model import repositories
@@ -47,7 +48,7 @@ class WhenTestingOrderRetryTaskRepository(database_utils.RepositoryTestCase):
         self.assertEqual(order_retry_task.id, order_retry_task_from_get.id)
         self.assertEqual(
             self.date_time_now, order_retry_task_from_get.retry_at)
-        self.assertEqual('retry-task', order_retry_task_from_get.retry_task)
+        self.assertEqual(u'retry-task', order_retry_task_from_get.retry_task)
         self.assertEqual(self.test_args, order_retry_task_from_get.retry_args)
         self.assertEqual(self.test_kwargs,
                          order_retry_task_from_get.retry_kwargs)
@@ -88,7 +89,7 @@ class WhenTestingOrderRetryTaskRepository(database_utils.RepositoryTestCase):
         order_retry_task_from_get = entities[0]
         self.assertEqual(order_retry_task.id, order_retry_task_from_get.id)
         self.assertEqual(date_time_future, order_retry_task_from_get.retry_at)
-        self.assertEqual('retry-task', order_retry_task_from_get.retry_task)
+        self.assertEqual(u'retry-task', order_retry_task_from_get.retry_task)
         self.assertEqual(self.test_args, order_retry_task_from_get.retry_args)
         self.assertEqual(self.test_kwargs,
                          order_retry_task_from_get.retry_kwargs)
@@ -102,7 +103,7 @@ class WhenTestingOrderRetryTaskRepository(database_utils.RepositoryTestCase):
 
         self.assertEqual([], entities)
         self.assertEqual(0, offset)
-        self.assertEqual(config.CONF.default_limit_paging, limit)
+        self.assertEqual(cfg.CONF.default_limit_paging, limit)
         self.assertEqual(0, total)
 
     def test_should_raise_no_result_found_with_exceptions(self):
@@ -120,7 +121,7 @@ class WhenTestingOrderRetryTaskRepository(database_utils.RepositoryTestCase):
 
         order_retry_task = models.OrderRetryTask()
         order_retry_task.order_id = order.id
-        order_retry_task.retry_task = 'retry-task'
+        order_retry_task.retry_task = u'retry-task'
         order_retry_task.retry_at = retry_at or self.date_time_now
         order_retry_task.retry_args = self.test_args
         order_retry_task.retry_kwargs = self.test_kwargs
