@@ -13,44 +13,43 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import base64
-from unittest import mock
 
+import mock
 import testtools
 
 from barbican.common import utils
 from barbican.model import models
-from barbican.plugin.crypto import base
+from barbican.plugin.crypto import crypto
 from barbican.plugin.interface import secret_store
 from barbican.plugin import store_crypto
-from barbican.tests import keys
 from barbican.tests import utils as test_utils
 
 
 def get_private_dto():
-    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 2048)
+    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 1024)
     return secret_store.SecretDTO(secret_store.SecretType.PRIVATE,
                                   base64.b64encode(
-                                      keys.get_private_key_pem()),
+                                      test_utils.get_private_key()),
                                   spec,
                                   'application/pkcs8')
 
 
 def get_public_dto():
-    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 2048)
+    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 1024)
     return secret_store.SecretDTO(secret_store.SecretType.PUBLIC,
                                   base64.b64encode(
-                                      keys.get_public_key_pem()),
+                                      test_utils.get_public_key()),
                                   spec,
                                   'application/octet-stream')
 
 
 def get_certificate_dto():
-    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 2048)
+    spec = secret_store.KeySpec(secret_store.KeyAlgorithm.RSA, 1024)
     return secret_store.SecretDTO(secret_store.SecretType.CERTIFICATE,
                                   base64.b64encode(
-                                      keys.get_certificate_pem()),
+                                      test_utils.get_certificate()),
                                   spec,
-                                  'application/octet-stream')
+                                  'application/pkix-cert')
 
 
 class TestSecretStoreBase(testtools.TestCase,
@@ -64,9 +63,9 @@ class TestSecretStoreBase(testtools.TestCase,
         self.project_id = '12345'
         self.content_type = 'application/octet-stream'
         self.content_encoding = 'base64'
-        self.secret = base64.b64encode(b'secret')
-        self.decrypted_secret = b'decrypted_secret'
-        self.cypher_text = b'cypher_text'
+        self.secret = base64.b64encode('secret')
+        self.decrypted_secret = 'decrypted_secret'
+        self.cypher_text = 'cypher_text'
         self.kek_meta_extended = 'kek-meta-extended'
         self.spec_aes = secret_store.KeySpec('AES', 64, 'CBC')
         self.spec_rsa = secret_store.KeySpec(
@@ -81,11 +80,11 @@ class TestSecretStoreBase(testtools.TestCase,
             secret_store.KeySpec(),
             self.content_type
         )
-        self.response_dto = base.ResponseDTO(
+        self.response_dto = crypto.ResponseDTO(
             self.cypher_text, kek_meta_extended=self.kek_meta_extended)
-        self.private_key_dto = base.ResponseDTO(self.cypher_text)
-        self.public_key_dto = base.ResponseDTO(self.cypher_text)
-        self.passphrase_dto = base.ResponseDTO(self.cypher_text)
+        self.private_key_dto = crypto.ResponseDTO(self.cypher_text)
+        self.public_key_dto = crypto.ResponseDTO(self.cypher_text)
+        self.passphrase_dto = crypto.ResponseDTO(self.cypher_text)
 
         self.kek_meta_project_model = models.KEKDatum()
         self.kek_meta_project_model.plugin_name = 'plugin-name'
@@ -99,7 +98,7 @@ class TestSecretStoreBase(testtools.TestCase,
         self.encrypted_datum_model.kek_meta_project = (
             self.kek_meta_project_model)
         self.encrypted_datum_model.cypher_text = base64.b64encode(
-            b'cypher_text')
+            'cypher_text')
         self.encrypted_datum_model.content_type = 'content_type'
         self.encrypted_datum_model.kek_meta_extended = 'extended_meta'
 
@@ -125,6 +124,7 @@ class TestSecretStoreBase(testtools.TestCase,
 
     def init_patchers(self):
         self._config_get_secret_repository()
+        self._config_get_project_secret_repository()
         self._config_get_encrypted_datum_repository()
         self._config_get_kek_datum_repository()
 
@@ -139,6 +139,12 @@ class TestSecretStoreBase(testtools.TestCase,
         self.secret_repo.create_from.return_value = self.secret_model
         self.setup_secret_repository_mock(self.secret_repo)
 
+    def _config_get_project_secret_repository(self):
+        """Mock the get_project_secret_repository() factory function."""
+        self.project_secret_repo = mock.MagicMock()
+        self.project_secret_repo.create_from.return_value = None
+        self.setup_project_secret_repository_mock(self.project_secret_repo)
+
     def _config_get_encrypted_datum_repository(self):
         """Mock the get_encrypted_datum_repository() factory function."""
         self.datum_repo = mock.MagicMock()
@@ -177,15 +183,15 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         response_dict = self.plugin_to_test.store_secret(
             self.secret_dto, self.context)
 
-        self.assertIsNone(response_dict)
+        self.assertEqual(None, response_dict)
 
         # Verify encrypt plugin and method where invoked.
         encrypt_mock = self.encrypting_plugin.encrypt
-        self.assertEqual(1, encrypt_mock.call_count)
+        self.assertEqual(encrypt_mock.call_count, 1)
         args, kwargs = encrypt_mock.call_args
         test_encrypt_dto, test_kek_meta_dto, test_project_id = tuple(args)
-        self.assertIsInstance(test_encrypt_dto, base.EncryptDTO)
-        self.assertEqual(b'secret', test_encrypt_dto.unencrypted)
+        self.assertIsInstance(test_encrypt_dto, crypto.EncryptDTO)
+        self.assertEqual('secret', test_encrypt_dto.unencrypted)
         self.assertEqual(self.kek_meta_dto, test_kek_meta_dto)
         self.assertEqual(self.project_id, test_project_id)
 
@@ -205,16 +211,16 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         response_dict = self.plugin_to_test.store_secret(
             secret_dto, self.context)
 
-        self.assertIsNone(response_dict)
+        self.assertEqual(None, response_dict)
 
         raw_content = base64.b64decode(secret_dto.secret)
 
         # Verify encrypt plugin and method where invoked.
         encrypt_mock = self.encrypting_plugin.encrypt
-        self.assertEqual(1, encrypt_mock.call_count)
+        self.assertEqual(encrypt_mock.call_count, 1)
         args, kwargs = encrypt_mock.call_args
         test_encrypt_dto, test_kek_meta_dto, test_project_id = tuple(args)
-        self.assertIsInstance(test_encrypt_dto, base.EncryptDTO)
+        self.assertIsInstance(test_encrypt_dto, crypto.EncryptDTO)
         self.assertEqual(raw_content, test_encrypt_dto.unencrypted)
         self.assertEqual(self.kek_meta_dto, test_kek_meta_dto)
         self.assertEqual(self.project_id, test_project_id)
@@ -231,7 +237,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         self.assertIsInstance(secret_dto, secret_store.SecretDTO)
         self.assertEqual(secret_store.SecretType.OPAQUE, secret_dto.type)
         self.assertEqual(
-            base64.encodebytes(self.decrypted_secret).rstrip(b'\n'),
+            base64.encodestring(self.decrypted_secret).rstrip('\n'),
             secret_dto.secret)
         self.assertEqual(
             self.encrypted_datum_model.content_type, secret_dto.content_type)
@@ -245,7 +251,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
 
         # Verify decrypt plugin and method where invoked.
         decrypt_mock = self.retrieving_plugin.decrypt
-        self.assertEqual(1, decrypt_mock.call_count)
+        self.assertEqual(decrypt_mock.call_count, 1)
         args, kwargs = decrypt_mock.call_args
         (
             test_decrypt,
@@ -254,12 +260,12 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
             test_project_id
         ) = tuple(args)
 
-        self.assertIsInstance(test_decrypt, base.DecryptDTO)
+        self.assertIsInstance(test_decrypt, crypto.DecryptDTO)
         self.assertEqual(
             base64.b64decode(self.encrypted_datum_model.cypher_text),
             test_decrypt.encrypted)
 
-        self.assertIsInstance(test_kek_meta, base.KEKMetaDTO)
+        self.assertIsInstance(test_kek_meta, crypto.KEKMetaDTO)
         self.assertEqual(
             self.kek_meta_project_model.plugin_name, test_kek_meta.plugin_name)
 
@@ -277,7 +283,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         secret_type = input_secret_dto.type
 
         decrypt_mock = self.retrieving_plugin.decrypt
-        decrypt_mock.return_value = base64.decodebytes(secret)
+        decrypt_mock.return_value = base64.decodestring(secret)
 
         secret_model = self.context.secret_model
         secret_model.algorithm = key_spec.alg
@@ -303,19 +309,19 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
 
     def test_generate_symmetric_key(self):
         """test symmetric secret generation."""
-        generation_type = base.PluginSupportTypes.SYMMETRIC_KEY_GENERATION
+        generation_type = crypto.PluginSupportTypes.SYMMETRIC_KEY_GENERATION
         self._config_determine_generation_type_private_method(
             generation_type)
 
         response_dict = self.plugin_to_test.generate_symmetric_key(
             self.spec_aes, self.context)
 
-        self.assertIsNone(response_dict)
+        self.assertEqual(None, response_dict)
 
         # Verify KEK objects finder was invoked.
         method_target = self.find_or_create_kek_objects_patcher.target
         method_mock = method_target._find_or_create_kek_objects
-        self.assertEqual(1, method_mock.call_count)
+        self.assertEqual(method_mock.call_count, 1)
 
         # Verify generating plugin and method where invoked.
         self._verify_generating_plugin_args(
@@ -326,7 +332,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         # Verify secret save was invoked.
         method_target = self.store_secret_and_datum_patcher.target
         method_mock = method_target._store_secret_and_datum
-        self.assertEqual(1, method_mock.call_count)
+        self.assertEqual(method_mock.call_count, 1)
 
     def test_generate_asymmetric_key_with_passphrase(self):
         """test asymmetric secret generation with passphrase."""
@@ -390,7 +396,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         )
 
     def test_should_raise_algorithm_not_supported_generate_symmetric_key(self):
-        generation_type = base.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION
+        generation_type = crypto.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION
         self._config_determine_generation_type_private_method(
             generation_type)
 
@@ -402,7 +408,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         )
 
     def test_should_raise_algo_not_supported_generate_asymmetric_key(self):
-        generation_type = base.PluginSupportTypes.SYMMETRIC_KEY_GENERATION
+        generation_type = crypto.PluginSupportTypes.SYMMETRIC_KEY_GENERATION
         self._config_determine_generation_type_private_method(
             generation_type)
 
@@ -417,7 +423,7 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         """test asymmetric secret generation with passphrase parameter."""
         self.spec_rsa.passphrase = passphrase
 
-        generation_type = base.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION
+        generation_type = crypto.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION
         self._config_determine_generation_type_private_method(
             generation_type)
 
@@ -427,14 +433,14 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
         # Verify response.
         self.assertIsInstance(
             response_dto, secret_store.AsymmetricKeyMetadataDTO)
-        self.assertIsNone(response_dto.private_key_meta)
-        self.assertIsNone(response_dto.public_key_meta)
-        self.assertIsNone(response_dto.passphrase_meta)
+        self.assertEqual(None, response_dto.private_key_meta)
+        self.assertEqual(None, response_dto.public_key_meta)
+        self.assertEqual(None, response_dto.passphrase_meta)
 
         # Verify KEK objects finder was invoked.
         method_target = self.find_or_create_kek_objects_patcher.target
         method_mock = method_target._find_or_create_kek_objects
-        self.assertEqual(1, method_mock.call_count)
+        self.assertEqual(method_mock.call_count, 1)
 
         # Verify generating plugin and method where invoked.
         self._verify_generating_plugin_args(
@@ -448,14 +454,14 @@ class WhenTestingStoreCrypto(TestSecretStoreBase):
             call_count = 3
         method_target = self.store_secret_and_datum_patcher.target
         method_mock = method_target._store_secret_and_datum
-        self.assertEqual(call_count, method_mock.call_count)
+        self.assertEqual(method_mock.call_count, call_count)
 
     def _verify_generating_plugin_args(self, generate_mock, alg, bit_length):
         """Verify generating plugin and method where invoked."""
-        self.assertEqual(1, generate_mock.call_count)
+        self.assertEqual(generate_mock.call_count, 1)
         args, kwargs = generate_mock.call_args
         test_generate_dto, test_kek_meta_dto, test_project_id = tuple(args)
-        self.assertIsInstance(test_generate_dto, base.GenerateDTO)
+        self.assertIsInstance(test_generate_dto, crypto.GenerateDTO)
         self.assertEqual(alg, test_generate_dto.algorithm)
         self.assertEqual(bit_length, test_generate_dto.bit_length)
         self.assertEqual(self.kek_meta_dto, test_kek_meta_dto)
@@ -528,25 +534,25 @@ class WhenTestingStoreCryptoDetermineGenerationType(testtools.TestCase):
     """Tests store_crypto.py's _determine_generation_type() function."""
 
     def test_symmetric_algorithms(self):
-        for algorithm in base.PluginSupportTypes.SYMMETRIC_ALGORITHMS:
+        for algorithm in crypto.PluginSupportTypes.SYMMETRIC_ALGORITHMS:
             self.assertEqual(
-                base.PluginSupportTypes.SYMMETRIC_KEY_GENERATION,
+                crypto.PluginSupportTypes.SYMMETRIC_KEY_GENERATION,
                 store_crypto._determine_generation_type(algorithm))
 
         # Case doesn't matter.
         self.assertEqual(
-            base.PluginSupportTypes.SYMMETRIC_KEY_GENERATION,
+            crypto.PluginSupportTypes.SYMMETRIC_KEY_GENERATION,
             store_crypto._determine_generation_type('AeS'))
 
     def test_asymmetric_algorithms(self):
-        for algorithm in base.PluginSupportTypes.ASYMMETRIC_ALGORITHMS:
+        for algorithm in crypto.PluginSupportTypes.ASYMMETRIC_ALGORITHMS:
             self.assertEqual(
-                base.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION,
+                crypto.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION,
                 store_crypto._determine_generation_type(algorithm))
 
         # Case doesn't matter.
         self.assertEqual(
-            base.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION,
+            crypto.PluginSupportTypes.ASYMMETRIC_KEY_GENERATION,
             store_crypto._determine_generation_type('RsA'))
 
     def test_should_raise_not_supported_no_algorithm(self):
@@ -581,7 +587,7 @@ class WhenTestingStoreCryptoFindOrCreateKekObjects(TestSecretStoreBase):
 
         # Verify returns.
         self.assertEqual(self.kek_meta_project_model, kek_model)
-        self.assertIsInstance(kek_meta_dto, base.KEKMetaDTO)
+        self.assertIsInstance(kek_meta_dto, crypto.KEKMetaDTO)
 
         # Verify the KEK repository interactions.
         self._verify_kek_repository_interactions(plugin_inst)
@@ -604,11 +610,11 @@ class WhenTestingStoreCryptoFindOrCreateKekObjects(TestSecretStoreBase):
 
         # Verify bind operations.
         self.assertEqual(
-            1, plugin_inst.bind_kek_metadata.call_count)
+            plugin_inst.bind_kek_metadata.call_count, 1)
         self.assertEqual(
-            1, self.bind_completed_mock.call_count)
+            self.bind_completed_mock.call_count, 1)
         self.assertEqual(
-            1, self.kek_repo.save.call_count)
+            self.kek_repo.save.call_count, 1)
         args, kwargs = self.kek_repo.save.call_args
         kek_model = args[0]
         self.assertEqual(self.kek_meta_project_model, kek_model)
@@ -619,7 +625,7 @@ class WhenTestingStoreCryptoFindOrCreateKekObjects(TestSecretStoreBase):
         plugin_inst.bind_kek_metadata.return_value = None
 
         self.assertRaises(
-            base.CryptoKEKBindingException,
+            crypto.CryptoKEKBindingException,
             store_crypto._find_or_create_kek_objects,
             plugin_inst,
             self.project_model)
@@ -627,7 +633,7 @@ class WhenTestingStoreCryptoFindOrCreateKekObjects(TestSecretStoreBase):
     def _verify_kek_repository_interactions(self, plugin_inst):
         """Verify the KEK repository interactions."""
         self.assertEqual(
-            1, self.kek_repo.find_or_create_kek_datum.call_count)
+            self.kek_repo.find_or_create_kek_datum.call_count, 1)
         args, kwargs = self.kek_repo.find_or_create_kek_datum.call_args
         test_project_model = args[0]
         test_full_plugin_name = args[1]
@@ -669,6 +675,7 @@ class WhenTestingStoreCryptoStoreSecretAndDatum(TestSecretStoreBase):
 
         # Verify the repository interactions.
         self._verify_secret_repository_interactions()
+        self._verify_project_secret_repository_interactions()
         self._verify_encrypted_datum_repository_interactions()
 
     def test_with_existing_secret(self):
@@ -683,27 +690,42 @@ class WhenTestingStoreCryptoStoreSecretAndDatum(TestSecretStoreBase):
 
         # Verify **not** these repository interactions.
         self.assertEqual(
-            0, self.secret_repo.create_from.call_count)
+            self.secret_repo.create_from.call_count, 0)
+        self.assertEqual(
+            self.project_secret_repo.create_from.call_count, 0)
 
     def _verify_secret_repository_interactions(self):
         """Verify the secret repository interactions."""
         self.assertEqual(
-            1, self.secret_repo.create_from.call_count)
+            self.secret_repo.create_from.call_count, 1)
         args, kwargs = self.secret_repo.create_from.call_args
         test_secret_model = args[0]
         self.assertEqual(self.secret_model, test_secret_model)
 
+    def _verify_project_secret_repository_interactions(self):
+        """Verify the project-secret repository interactions."""
+        self.assertEqual(
+            self.project_secret_repo.create_from.call_count, 1)
+        args, kwargs = self.project_secret_repo.create_from.call_args
+        test_project_secret_model = args[0]
+        self.assertIsInstance(test_project_secret_model, models.ProjectSecret)
+        self.assertEqual(
+            self.context.project_model.id,
+            test_project_secret_model.project_id)
+        self.assertEqual(
+            models.States.ACTIVE, test_project_secret_model.status)
+
     def _verify_encrypted_datum_repository_interactions(self):
         """Verify the encrypted datum repository interactions."""
         self.assertEqual(
-            1, self.datum_repo.create_from.call_count)
+            self.datum_repo.create_from.call_count, 1)
         args, kwargs = self.datum_repo.create_from.call_args
         test_datum_model = args[0]
         self.assertIsInstance(test_datum_model, models.EncryptedDatum)
         self.assertEqual(
             self.content_type, test_datum_model.content_type)
         self.assertEqual(
-            base64.encodebytes(self.cypher_text).rstrip(b'\n'),
+            base64.encodestring(self.cypher_text).rstrip('\n'),
             test_datum_model.cypher_text)
         self.assertEqual(
             self.response_dto.kek_meta_extended,
@@ -714,7 +736,7 @@ class WhenTestingStoreCryptoIndicateBindCompleted(TestSecretStoreBase):
     """Tests store_crypto.py's _indicate_bind_completed() function."""
 
     def test_bind_operation(self):
-        kek_meta_dto = base.KEKMetaDTO(self.kek_meta_project_model)
+        kek_meta_dto = crypto.KEKMetaDTO(self.kek_meta_project_model)
         self.kek_meta_project_model.bind_completed = False
 
         store_crypto._indicate_bind_completed(
@@ -722,10 +744,10 @@ class WhenTestingStoreCryptoIndicateBindCompleted(TestSecretStoreBase):
 
         self.assertTrue(self.kek_meta_project_model.bind_completed)
         self.assertEqual(
-            self.kek_meta_project_model.algorithm, kek_meta_dto.algorithm)
+            kek_meta_dto.algorithm, self.kek_meta_project_model.algorithm)
         self.assertEqual(
-            self.kek_meta_project_model.bit_length, kek_meta_dto.bit_length)
+            kek_meta_dto.bit_length, self.kek_meta_project_model.bit_length)
         self.assertEqual(
-            self.kek_meta_project_model.mode, kek_meta_dto.mode)
+            kek_meta_dto.mode, self.kek_meta_project_model.mode)
         self.assertEqual(
-            self.kek_meta_project_model.plugin_meta, kek_meta_dto.plugin_meta)
+            kek_meta_dto.plugin_meta, self.kek_meta_project_model.plugin_meta)
