@@ -12,13 +12,14 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from oslo_utils import uuidutils
+import uuid
 
 import mock
-import oslo_messaging
-from oslo_service import service
+from oslo import messaging
+from oslo_config import cfg
+import six
 
-from barbican.common import config
+from barbican.openstack.common import service
 from barbican import queue
 from barbican.queue import keystone_listener
 from barbican.tasks import keystone_consumer as consumer
@@ -29,13 +30,13 @@ class UtilMixin(object):
 
     def __init__(self, *args, **kwargs):
         super(UtilMixin, self).__init__(*args, **kwargs)
-        self.conf = config.CONF
+        self.conf = cfg.CONF
         # dict which has item as {property: (value, group_name)}
         self.overrides = {}
 
     def revert_overrides(self):
         '''Reverts configuration override values after test end.'''
-        for k, v in self.overrides.items():
+        for k, v in six.iteritems(self.overrides):
             value, group = v
             self.conf.set_override(k, value, group)
 
@@ -44,7 +45,7 @@ class UtilMixin(object):
         self.addCleanup(self.revert_overrides)
 
     def opt_in_group(self, group, **kw):
-        for k, v in kw.items():
+        for k, v in six.iteritems(kw):
             # add to local overrides if its not already set
             # we want to keep the original value from first override
             dict_value = self.overrides.get(k)
@@ -64,8 +65,7 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
         super(WhenUsingNotificationTask, self).setUp()
 
         self.task = keystone_listener.NotificationTask(self.conf)
-        self.payload = {'resource_info': uuidutils.generate_uuid(
-            dashed=False)}
+        self.payload = {'resource_info': uuid.uuid4().hex}
 
         self.type_index = 2
         self.payload_index = 3
@@ -102,21 +102,21 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
     def test_delete_project_event_notification_with_required_data(
             self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'identity.project.deleted'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
         mock_process.assert_called_once_with(project_id=project_id,
                                              operation_type='deleted',
                                              resource_type='project')
-        self.assertEqual(oslo_messaging.NotificationResult.HANDLED, result)
+        self.assertEqual(messaging.NotificationResult.HANDLED, result)
 
     @mock.patch.object(consumer.KeystoneEventConsumer, 'process',
                        return_value=None)
     def test_delete_project_event_with_different_service_name_in_event_type(
             self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'aaa.project.deleted'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
@@ -124,14 +124,14 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
         mock_process.assert_called_once_with(project_id=project_id,
                                              operation_type='deleted',
                                              resource_type='project')
-        self.assertEqual(oslo_messaging.NotificationResult.HANDLED, result)
+        self.assertEqual(messaging.NotificationResult.HANDLED, result)
 
     @mock.patch.object(consumer.KeystoneEventConsumer, 'process',
                        return_value=None)
     def test_delete_project_event_with_event_type_in_different_case(
             self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'Identity.PROJECT.DeleteD'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
@@ -139,14 +139,14 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
         mock_process.assert_called_once_with(project_id=project_id,
                                              operation_type='deleted',
                                              resource_type='project')
-        self.assertEqual(oslo_messaging.NotificationResult.HANDLED, result)
+        self.assertEqual(messaging.NotificationResult.HANDLED, result)
 
     @mock.patch.object(consumer.KeystoneEventConsumer, 'process',
                        return_value=None)
     def test_delete_project_event_with_incomplete_event_type_format(
             self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'project.deleted'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
@@ -201,7 +201,7 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
                        return_value=None)
     def test_event_notification_with_missing_event_type(self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = None
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
@@ -215,7 +215,7 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
                        return_value=None)
     def test_event_notification_with_blank_event_type(self, mock_process):
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = ''
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = self.task.info(*self.task_args)
@@ -233,14 +233,14 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
         local_task = keystone_listener.NotificationTask(self.conf)
         mock_process.side_effect = Exception('Dummy Error')
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'identity.project.deleted'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = local_task.info(*self.task_args)
 
         self.assertTrue(mock_process.called, 'Should call event consumer for'
                         ' project delete event')
-        self.assertEqual(oslo_messaging.NotificationResult.HANDLED, result)
+        self.assertEqual(messaging.NotificationResult.HANDLED, result)
 
     @mock.patch.object(consumer.KeystoneEventConsumer, 'process')
     def test_event_notification_with_processing_error_requeue_enabled(
@@ -250,14 +250,14 @@ class WhenUsingNotificationTask(UtilMixin, utils.BaseTestCase):
         local_task = keystone_listener.NotificationTask(self.conf)
         mock_process.side_effect = Exception('Dummy Error')
 
-        project_id = uuidutils.generate_uuid(dashed=False)
+        project_id = uuid.uuid4().hex
         self.task_args[self.type_index] = 'identity.project.deleted'
         self.task_args[self.payload_index] = {'resource_info': project_id}
         result = local_task.info(*self.task_args)
 
         self.assertTrue(mock_process.called, 'Should call event consumer for'
                         ' project delete event')
-        self.assertEqual(oslo_messaging.NotificationResult.REQUEUE, result)
+        self.assertEqual(messaging.NotificationResult.REQUEUE, result)
 
 
 class WhenUsingMessageServer(UtilMixin, utils.BaseTestCase):
@@ -267,8 +267,7 @@ class WhenUsingMessageServer(UtilMixin, utils.BaseTestCase):
         super(WhenUsingMessageServer, self).setUp()
         queue.init(self.conf)
 
-        patcher = mock.patch('oslo_messaging.notify.listener.'
-                             'NotificationServer')
+        patcher = mock.patch('oslo_messaging.server.MessageHandlingServer')
         mock_server_class = patcher.start()
         self.addCleanup(patcher.stop)
 
@@ -318,7 +317,7 @@ class WhenUsingMessageServer(UtilMixin, utils.BaseTestCase):
         msg_server.start()
         self.msg_server_mock.start.assert_called_with()
 
-    @mock.patch.object(service.Service, 'stop', autospec=True)
+    @mock.patch.object(service.Service, 'stop')
     def test_should_stop(self, mock_service_stop):
         msg_server = keystone_listener.MessageServer(self.conf)
         msg_server.stop()
