@@ -12,9 +12,9 @@ if [ ! -d $LOCAL_CONFIG_DIR ];
 then
   LOCAL_CONFIG_DIR=../etc/barbican
 fi
-LOCAL_CONFIG=$LOCAL_CONFIG_DIR/barbican.conf
+LOCAL_CONFIG=$LOCAL_CONFIG_DIR/barbican-api.conf
 
-DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
+DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
 echo 'DIR: '$DIR
 
 debug_barbican()
@@ -93,6 +93,12 @@ install_barbican()
     # Install source code into the Python path as if packaged.
     pip install -e .
 
+    # If using pyenv, rehash now.
+    hash pyenv &> /dev/null
+    if [ $? -eq 0 ]; then
+       pyenv rehash
+    fi
+
     # Run unit tests
     python setup.py testr
 
